/*
 * Descent 3
 * Copyright (C) 2024 Parallax Software
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by editor.rc
//
#define IDC_LOAD 2
#define IDCANCEL2 3
#define IDC_DOORWAY_EMPTY10 3
#define ID_SCRIPTEDITOR_COPY 3
#define IDC_AI_FLYER_BUTTON 3
#define IDR_SRVR_INPLACE 4
#define ID_SCRIPTEDITOR_CUT 4
#define IDC_AI_WALKER_BUTTON 4
#define IDR_SRVR_EMBEDDED 5
#define ID_SCRIPTEDITOR_PASTE 5
#define IDC_AI_TURRET_BUTTON 5
#define ID_SCRIPTEDITOR_FIND 6
#define IDC_AI_MELEE_BUTTON 6
#define ID_SCRIPTEDITOR_FINDREPLACE 7
#define ID_SCRIPTEDITOR_EXPORT 8
#define ID_SCRIPTEDITOR_IMPORT 9
#define IDCANCEL4 11
#define IDC_DOORWAY_EMPTY12 11
#define IDCANCEL5 12
#define IDC_DOORWAYPAD_EMPTY13 12
#define IDCANCEL6 13
#define IDC_DOORWAY_EMPTY14 13
#define IDCANCEL7 14
#define IDC_DOORWAYPAD_EMPTY5 14
#define IDCANCEL8 15
#define IDC_DOORWAYPAD_EMPTY6 15
#define IDCANCEL9 16
#define IDC_DOORWAYPAD_EMPTY7 16
#define IDCANCEL10 17
#define IDC_DOORWAYPAD_EMPTY17 17
#define IDCANCEL11 18
#define IDC_PLAYPAD_EMPTY1 18
#define IDCANCEL12 19
#define IDC_DOORWAYPAD_EMPTY2 19
#define IDCANCEL13 20
#define IDC_DOORWAYPAD_EMPTY3 20
#define IDCANCEL14 21
#define IDC_DOORWAYPAD_EMPTY4 21
#define IDCANCEL15 22
#define IDC_DOORWAY_EMPTY11 22
#define IDCANCEL16 23
#define IDC_CURVE_ENDUP 23
#define IDCANCEL17 24
#define IDC_CURVEPAD_ENDLEFT 24
#define IDCANCEL18 25
#define IDC_CURVE_ENDRIGHT 25
#define IDCANCEL19 26
#define IDC_CURVE_ENDDOWN 26
#define IDP_OLE_INIT_FAILED 100
#define IDD_ABOUTBOX 100
#define IDD_WORLDSOUNDS 101
#define ID_INDICATOR_CURSEG 101
#define ID_INDICATOR_MARKSEG 102
#define IDD_KEYPAD_DLGBAR 103
#define ID_INDICATOR_PLAYERPOS 103
#define ID_INDICATOR_NET 104
#define ID_ACCEL_SLIDERIGHT 104
#define ID_INDICATOR_BMMEM 105
#define ID_ACCEL_SLIDELEFT 105
#define ID_ACCEL_SLIDEUP 106
#define ID_ACCEL_SLIDEDOWN 107
#define ID_ACCEL_COPY_LIGHT_MULTIPLE 108
#define ID_ACCEL_NEXTVERTEX 109
#define IDR_MAINFRAME 128
#define IDR_EDITORTYPE 129
#define IDD_TEXTUREKEYPAD 130
#define IDB_MATTHEAD 131
#define IDD_FONT_DIALOG 133
#define IDD_FLOATING_KEYPAD 134
#define IDD_PREFERENCES 136
#define IDD_HOGDIALOG 137
#define IDD_TERRAINKEYPAD 144
#define IDD_D3SPLASH 145
#define IDB_D3SPLASH 147
#define IDD_PATHKEYPAD 148
#define IDD_OBJECTKEYPAD 151
#define IDD_LIGHTINGKEYPAD 152
#define IDD_EDITLINEDLG 154
#define IDD_TRIGGERKEYPAD 155
#define IDD_PLAYERKEYPAD 156
#define IDD_WORLDOBJECTSPLAYER 157
#define IDD_CUSTOMIZE_OBJECT 158
#define IDD_WORLDOBJECTSDOOR 159
#define IDD_WORLDOBJECTSLIGHT 160
#define IDD_ANIMSTATES 161
#define IDD_FILEPAGE 162
#define IDD_WORLDTEXTURES 163
#define IDD_WORLDOBJECTSPOWERUP 164
#define IDD_WORLDWEAPONS 165
#define IDD_STATUS 166
#define IDD_WORLDOBJECTSROBOT 167
#define IDD_DOORWAYKEYPAD 168
#define IDD_POWPROP_DIALOG 169
#define IDD_MEGACELL 170
#define IDD_MEGAKEYPAD 172
#define IDD_ROOMKEYPAD 173
#define IDD_OBJECTPROPERTIES 174
#define IDD_PROPPHYSICS 175
#define IDD_PROPAI 176
#define IDD_PROPSCRIPT 177
#define IDD_STATUSDLG 178
#define IDD_SCRIPTEDITOR 179
#define IDD_OSIRIS_STATUS 180
#define IDR_OSIRIS 181
#define IDD_SELECTRANGE_DIALOG 182
#define IDD_PHYSICS 183
#define IDD_AI 184
#define IDD_WORLDOBJECTSGENERIC 185
#define IDD_SCRIPTWIZ 188
#define IDD_SCRIPTSTUDIO 189
#define IDD_ROBOT_WEAPON_DIALOG 191
#define IDB_NORTH 208
#define IDB_EAST 209
#define IDB_SOUTH 210
#define IDB_WEST 211
#define IDB_ROTATELEFT 212
#define IDB_ROTATERIGHT 213
#define IDB_OUTARROW 214
#define IDB_INARROW 215
#define IDD_GENERICLIGHT 217
#define IDD_LEVELPROPERTIES 218
#define IDD_SCRIPTSELECT 219
#define IDD_ADDSCRIPT 220
#define IDD_PLAYER_WEAPONS 221
#define IDD_SCRIPTPARMS 222
#define IDD_OBJTREEDLG 224
#define IDD_LEVEL_INFO 226
#define IDD_PROCEDURAL_DIALOG 227
#define IDD_TABLE_FILE_EDITOR 228
#define IDR_TABLE_FILE_EDIT_MENU 229
#define IDD_WATER_PROCEDURAL 230
#define IDD_AMBIENTSOUNDPATTERNS 231
#define IDD_AMBIENTSOUNDELEMENT 232
#define IDD_MATCENKEYPAD 233
#define IDD_LEVELKEYPAD 234
#define IDD_BRIEF_MAIN 235
#define IDD_BRIEF_ADDSCREEN 236
#define IDD_BRIEF_ADDTEXT 237
#define IDD_BRIEF_ADDBITMAP 238
#define IDD_BRIEF_ADDMOVIE 239
#define IDD_BRIEF_ADDSOUND 241
#define IDD_BRIEF_ADDBUTTON 242
#define IDD_LOCALIZESCRIPT 243
#define IDD_FORCEFEEDBACK 245
#define IDD_TABLE_FILE_FILTER 246
#define IDR_TABLE_FILE_FILTER_MENU 247
#define IDD_TABLEFILEFILTER_ADDPAGE_DLG 248
#define IDD_MULTICHECK 250
#define IDD_SCRIPTINTERFACE 251
#define IDD_DALLAS_MAIN_DIALOG 252
#define IDD_CREATESCRIPT 253
#define IDD_CONFIGCOMPILER 254
#define IDD_DALLAS_GENERIC_PROMPT_DIALOG 255
#define IDB_DALLAS_TREE_ICONS_BITMAP 256
#define IDD_DALLAS_VECTOR_DIALOG 258
#define IDD_COMPILEALL 259
#define IDD_QUICKCOMPILE 260
#define IDD_LIGHTINGSTATUS 261
#define IDD_BRIEFMISSIONFLAGS 262
#define IDD_DEATH_DIALOG 263
#define IDD_DALLAS_SOUND_DIALOG 265
#define IDD_DALLAS_FLAG_DIALOG 266
#define IDD_CUSTDEFSCRIPT 267
#define IDD_DALLAS_TEXTURE_DIALOG 268
#define IDD_DALLAS_USERTYPES_DIALOG 269
#define IDD_DALLAS_IMPORT_DIALOG 270
#define IDD_BRIEF_MANAGE 271
#define IDD_FILEPAGEADD 272
#define IDD_DALLAS_STRM_AUDIO_DIALOG 273
#define IDD_TERRAIN_SOUND_DIALOG 274
#define IDD_SOUNDSOURCE_DIALOG 275
#define IDD_SYNCSCRIPTS 276
#define IDD_GENERIC_DEATHS 277
#define IDD_ORPHAN 278
#define IDB_ORPHREMOVE 280
#define IDD_VIEWER_DIALOG 282
#define IDC_DLGBAR_KEYPAD 1000
#define IDC_EVENT_TREE 1000
#define IDC_KEYPADS 1001
#define IDC_SOUNDHALLEFFECT_CHECK 1001
#define IDC_HELP_EDIT 1001
#define IDC_TEXTUREPAD_GROUP 1002
#define IDC_SOUNDFOREVER_CHECK 1002
#define IDC_TABLEEDIT_MAIN_GROUP 1002
#define IDC_TEXTURE_GROUP 1003
#define IDC_SOUNDMAXDIST_EDIT 1003
#define IDC_TABLEEDIT_NAME_LIST 1003
#define IDC_MESSAGE_LIST 1003
#define IDC_TEXTURE_LISTBOX 1004
#define IDC_SOUNDMINDIST_EDIT 1004
#define IDC_TABLEEDIT_DESCRIPTION_EDIT 1004
#define IDC_MESSAGE_EDIT 1004
#define IDC_TEXPAD_SLIDELEFT 1005
#define IDC_SOUNDINNERCONEANGLE_EDIT 1005
#define IDC_RADIO1 1006
#define IDC_PROP_MONO 1006
#define IDC_LIGHT_FADEINOUT 1006
#define IDC_TRIGGER_OPENDOOR 1006
#define IDC_DOORWAY_LOCKED 1006
#define IDC_SOUNDOUTERCONEANGLE_EDIT 1006
#define IDC_ENERGY_RADIO 1006
#define IDC_AI_PTMC_RADIO 1006
#define IDC_WB_NO_ANIM_RADIO 1006
#define IDC_SRC_BUMP 1006
#define IDC_ONOFF_RADIO 1006
#define IDC_INVTYPE_MISSION 1006
#define IDC_USE_D3D 1006
#define IDC_LEVEL_GOAL_ROOM_ITEM_RADIO 1006
#define IDC_RADIO_LEVELS 1006
#define IDC_LEVEL 1006
#define IDC_OPTIMIZE 1006
#define IDC_LOCKED 1006
#define IDC_D_FLAG1 1006
#define IDC_DEATH_DELAY_FIREBALLS 1006
#define IDC_NONE_RADIO 1006
#define IDC_BRIEF_BT_JUMP 1006
#define IDC_AIN_VIEW_ALL_NODES 1006
#define IDC_RADIO2 1007
#define IDC_PROP_GRADIANT 1007
#define IDC_LIGHT_NORMAL 1007
#define IDC_TRIGGER_CLOSEDOOR 1007
#define IDC_DOORWAY_UNLOCKED 1007
#define IDC_SOUNDOUTERCONEVOL_EDIT 1007
#define IDC_DOORWAY_BLASTABLE 1007
#define IDC_MATTER_RADIO 1007
#define IDC_FIRES_NORMALLY 1007
#define IDC_AI_REBEL_RADIO 1007
#define IDC_WB_LOCAL_ANIM_RADIO 1007
#define IDC_BUMP1 1007
#define IDC_INVTYPE_GAME 1007
#define IDC_LEVEL_GOAL_OBJ_ITEM_RADIO 1007
#define IDC_RADIO_SCRIPTS 1007
#define IDC_MESSAGE_NAME_EDIT 1007
#define IDC_GAME 1007
#define IDC_COFF 1007
#define IDC_NOTLOCKED 1007
#define IDC_DEATH_DELAY_FLYING 1007
#define IDC_SPECIFIC_RADIO 1007
#define IDC_DOORWAY_KEY_ALL 1007
#define IDC_AIN_VIEW_ROOM_AND_NEXT_ROOMS 1007
#define IDC_RADIO3 1008
#define IDC_PROP_BITMAPPED 1008
#define IDC_SOUND_DESCRIP 1008
#define IDC_TRIGGER_MATCEN 1008
#define IDC_FIRES_FUSION 1008
#define IDC_BUMP2 1008
#define IDC_DEATH_DELAY_SPARKS 1008
#define IDC_RADIO4 1009
#define IDC_TRIGGER_EXIT 1009
#define IDC_WEAPON_XAXIS_RADIO 1009
#define IDC_BARREL_3_RADIO 1009
#define IDC_OBJMOVEXY 1009
#define IDC_BUMP3 1009
#define IDC_ZOOM_RADIO 1009
#define IDC_DEATH_DELAY_PLAIN 1009
#define IDC_DEATH_DELAY_MIN_MAX 1009
#define IDC_DEATH_DELAY_NO_TUMBLE 1009
#define IDC_RADIO5 1010
#define IDC_WEAPON_YAXIS_RADIO2 1010
#define IDC_BARREL_4_RADIO 1010
#define IDC_OBJMOVEP 1010
#define IDC_BUMP4 1010
#define IDC_MAT_RANDOM_RADIO 1010
#define IDC_WARN_LOW 1010
#define IDC_DEATH_DELAY_NONE 1010
#define IDC_LG_ENTER_RADIO 1010
#define IDC_RADIO6 1011
#define IDC_TRIGGER_ILLUSIONOFF 1011
#define IDC_SOUNDOBJECT_RADIO 1011
#define IDC_WEAPON_ZAXIS_RADIO 1011
#define IDC_BARREL_5_RADIO 1011
#define IDC_OBJMOVEH 1011
#define IDC_MAT_WPN_RADIO 1011
#define IDC_CORONA_A 1011
#define IDC_WARN_MED 1011
#define IDC_DEATH_EXPLOSION_SMALL 1011
#define IDC_LG_DESTROYED_RADIO 1011
#define IDC_AIN_SEL_NODE_EDGES 1011
#define IDC_RADIO7 1012
#define IDC_TRIGGER_UNLOCKDOOR 1012
#define IDC_SOUNDTURRET1_RADIO 1012
#define IDC_BARREL_6_RADIO 1012
#define IDC_OBJMOVEB 1012
#define IDC_MAT_APV_RADIO 1012
#define IDC_CORONA_B 1012
#define IDC_WARN_HIGH 1012
#define IDC_DEATH_EXPLOSION_MEDIUM 1012
#define IDC_LG_DALLAS_RADIO 1012
#define IDC_AIN_SEL_ROOM 1012
#define IDC_RADIO8 1013
#define IDC_TRIGGER_OPENWALL 1013
#define IDC_SOUNDTURRET2_RADIO 1013
#define IDC_BARREL_7_RADIO 1013
#define IDC_OBJMOVEPH 1013
#define IDC_MAT_WPV_RADIO 1013
#define IDC_CORONA_C 1013
#define IDC_DEATH_EXPLOSION_LARGE 1013
#define IDC_RADIO9 1014
#define IDC_TRIGGER_LOCKDOOR 1014
#define IDC_SOUNDTURRET3_RADIO 1014
#define IDC_MAT_APN_RADIO 1014
#define IDC_CORONA_D 1014
#define IDC_EXPORT_BUTTON 1014
#define IDC_DEATH_CONTACT_BREAKS_APART 1014
#define IDC_LG_PPW_COLLIDE_RADIO 1014
#define IDC_RADIO10 1015
#define IDC_TRIGGER_CLOSEWALL 1015
#define IDC_SOUNDFORWARD_RADIO 1015
#define IDC_MAT_UNASSIGNED_RADIO 1015
#define IDC_DEATH_CONTACT_EXPLODES 1015
#define IDC_BUTTON1 1016
#define IDC_DEATH_CONTACT_DISAPPEARS 1016
#define IDC_BUTTON2 1017
#define IDC_COMBO3 1017
#define IDC_RADIO11 1017
#define IDC_SOUNDBACKWARD_RADIO 1017
#define IDC_GENERIC_EXPLOSION_SOUND_COMBO 1017
#define IDC_SMALLIMG_PULLDOWN 1017
#define IDC_ROOM_ENVAUDIO 1017
#define IDC_ENVAUD_LIST 1017
#define IDC_DEATH_CONTACT_REMAINS 1017
#define IDC_LEVELGOAL_ROOM_COMBO 1017
#define IDC_BUTTON3 1018
#define IDC_COMBO4 1018
#define IDC_AI_INITIAL_ACTION_COMBO 1018
#define IDC_SPAWN2_PULLDOWN 1018
#define IDC_RADIO15 1018
#define IDC_LEVELGOALTRIGGER_COMBO 1018
#define IDC_DEATH_DELAY_SMOKE 1018
#define IDC_BUTTON9 1019
#define IDC_COMBO5 1019
#define IDC_BUTTON8 1019
#define IDC_LIST1 1019
#define IDC_TEXPAD_TMAP2 1019
#define IDC_AI_TYPE_COMBO 1019
#define IDC_SPAWN_ROBOT_PULLDOWN 1019
#define IDC_DEATH_DEBRIS_CONTACT_EXPLODES 1019
#define IDC_LEVELGOALOBJECT_COMBO 1019
#define IDC_COMBO9 1020
#define IDC_BUTTON4 1020
#define IDC_RADIO12 1020
#define IDC_TRIGGER_REMOVETRIG 1020
#define IDC_DOORWAY_DOORNEXT 1020
#define IDC_WEAPONS_OUT 1020
#define IDC_TERR_MORE_MOONS 1020
#define IDC_SOUNDUPWARD_RADIO 1020
#define IDC_DELETE_FILE 1020
#define IDC_CONVERT_TO_SMALL 1020
#define IDC_UNDOLOCK 1020
#define IDC_TRIG_ADD_FLOATING 1020
#define IDC_ASP_DELETE 1020
#define IDC_LEVEL_COPY_GOAL_BUTTON 1020
#define IDC_COMPILE 1020
#define IDC_INSERT_EVENT_BUTTON 1020
#define IDC_DEATH_DEBRIS_CONTACT_DISAPPEARS 1020
#define IDC_AIN_INSERT_NODE_ON_EDGE 1020
#define IDC_ALIGN_YPOS_BUTTON 1020
#define IDC_FFT1_COMBO 1020
#define IDC_COMBO10 1021
#define IDC_BUTTON5 1021
#define IDC_TRIGGER_CLEARBINDINGS 1021
#define IDC_TERR_NEXT_MOON 1021
#define IDC_DEATH_DEBRIS_CONTACT_REMAINS 1021
#define IDC_ALIGN_YNEG_BUTTON 1021
#define IDC_FFT2_COMBO 1021
#define IDC_BUTTON6 1022
#define IDC_COMBO11 1022
#define IDC_RADIO13 1022
#define IDC_BUTTON37 1022
#define IDC_TRIGGER_MAKEILLUSORY 1022
#define IDC_LOAD_SOUND 1022
#define IDC_NEXT_FILE 1022
#define IDC_EDITSCRIPT 1022
#define IDC_TRIG_CHANGE_SCRIPT 1022
#define IDC_AI_ATTACK_SOUND_COMBO 1022
#define IDC_ASP_LOCK 1022
#define IDC_MAT_MOVE_VIEWER_BUTTON 1022
#define IDC_LEVEL_GOAL_PREV_ITEM_BUTTON 1022
#define IDC_COPY_BUTTON 1022
#define IDC_S_FLAG1 1022
#define IDC_AIN_DELETE_NODE 1022
#define IDC_ALIGN_ZPOS_BUTTON 1022
#define IDC_COMBO6 1023
#define IDC_BUTTON10 1023
#define IDC_AI_SEE_SOUND_COMBO 1023
#define IDC_LEVEL_GOAL_GOTO_ITEM_BUTTON 1023
#define IDC_COMBO7 1024
#define IDC_BUTTON13 1024
#define IDC_RADIO14 1024
#define IDC_TRIGGER_LIGHTON 1024
#define IDC_PSHIP_NEXT 1024
#define IDC_SOUNDDOWNWARD_RADIO 1024
#define IDC_AI_FLEE_SOUND_COMBO 1024
#define IDC_BRIEF_EFFECT_MOVIE 1024
#define IDC_LEVEL_GOAL_NEW_ITEM_BUTTON 1024
#define IDC_AIN_DELETE_EDGE 1024
#define IDC_ALIGN_UPYPOS_BUTTON 1024
#define IDC_COMBO8 1025
#define IDC_BUTTON14 1025
#define IDC_WTEXDLG_ADDNEW 1025
#define IDC_AI_ANGRY_SOUND_COMBO 1025
#define IDC_LEVEL_GOAL_PASTE_OBJREF_ITEM_BUTTON 1025
#define IDC_FFOS_COMBO 1025
#define IDC_LIST4 1026
#define IDC_BUTTON15 1026
#define IDC_COMBO13 1026
#define IDC_COMBO2 1026
#define IDC_DOORTYPE 1026
#define IDC_PALETTIZED_PULLDOWN 1026
#define IDC_ROBOT_PULLDOWN 1026
#define IDC_CURRENT_ANIMATION_PULLDOWN 1026
#define IDC_FILENAME_PULLDOWN 1026
#define IDC_SCRMOD_BOX 1026
#define IDC_CURRENT_GB_COMBO 1026
#define IDC_AI_MOVEMENT_TYPE_COMBO 1026
#define IDC_PARTICLE_PULLDOWN 1026
#define IDC_MAT_PROD_0_COMBO 1026
#define IDC_AMB_TYPE1 1026
#define IDC_LIST_DRIVES 1026
#define IDC_TERRAIN_SOUND_COMBO 1026
#define IDC_AIN_MOVE_NODE_TO_VIEWER 1026
#define IDC_COMBO14 1027
#define IDC_BUTTON22 1027
#define IDC_OBJPAD_FLAGOBJMULTI 1027
#define IDC_AI_MOVEMENT_SUBTYPE_COMBO 1027
#define IDC_GRAVITY_PULLDOWN 1027
#define IDC_MAT_PROD_2_COMBO 1027
#define IDC_AMB_TYPE2 1027
#define IDC_AIN_MPNS 1027
#define IDC_BUTTON17 1028
#define IDC_COMBO15 1028
#define IDC_OBJ_SHOW_SURFACE 1028
#define IDC_GENERIC_AMBIENT_SOUND_COMBO 1028
#define IDC_BRIEF_EFFECT_BUTTON 1028
#define IDC_MAT_PROD_1_COMBO 1028
#define IDC_AI_TURRET_SOUND_COMBO 1028
#define IDC_AMB_TYPE3 1028
#define IDC_MVTN_BUTTON 1028
#define IDC_BUTTON7 1029
#define IDC_COMBO16 1029
#define IDC_MAT_PROD_3_COMBO 1029
#define IDC_AMB_TYPE4 1029
#define IDC_BUTTON11 1030
#define IDC_COMBO17 1030
#define IDC_OBJ_CONT_PREVIEW 1030
#define IDC_BRIEF_SCREEN_EDIT 1030
#define IDC_MAT_PROD_4_COMBO 1030
#define IDC_AMB_TYPE5 1030
#define IDC_AIN_UP 1030
#define IDC_BUTTON12 1031
#define IDC_COMBO18 1031
#define IDC_BUTTON32 1031
#define IDC_ROBOTS_OUT 1031
#define IDC_BRIEF_SCREEN_ADD 1031
#define IDC_MAT_PROD_5_COMBO 1031
#define IDC_AMB_TYPE6 1031
#define IDC_AIN_RIGHT 1031
#define IDC_CHECK2 1032
#define IDC_COMBO19 1032
#define IDC_BUTTON23 1032
#define IDC_PULSE 1032
#define IDC_DISABLE_PORTAL_FLYTHROUGH 1032
#define IDC_MAX_DISTANCE_CHECK 1032
#define IDC_ENABLE_PORTAL_FLYTHROUGH 1032
#define IDC_TRIG_ACTIV_PLAYER_WEAPONS 1032
#define IDC_PHYSICS_AUTO_LEVELING_CHECK 1032
#define IDC_HEARS_NOISE_CHECK 1032
#define IDC_LAUNCH_ALTERNATE 1032
#define IDC_LIGHT_CHECK 1032
#define IDC_SOUND_FORCE_HARWARE_CHECK 1032
#define IDC_RING 1032
#define IDC_FIRING_RELEASE_SOUND 1032
#define IDC_INVEN_VISWHENUSED 1032
#define IDC_BLUE_CHECK 1032
#define IDC_MAT_PROD_6_COMBO 1032
#define IDC_DEATH_EXPLODES 1032
#define IDC_RANDOM_CHECK 1032
#define IDC_DEATH_FIREBALL 1032
#define IDC_BGOS_COMBO 1032
#define IDC_CHECK3 1033
#define IDC_COMBO20 1033
#define IDC_BUTTON24 1033
#define IDC_SOUNDPASTE_BUTTON 1033
#define IDC_XZ_PLANE_ANGLE_CHECK 1033
#define IDC_TRIG_ACTIV_ROBOTS 1033
#define IDC_JOIN_BATTLES_CHECK 1033
#define IDC_SATURATE 1033
#define IDC_PLANAR_BLAST 1033
#define IDC_PHYSICS_POINT_WALL_CHECK 1033
#define IDC_ROOMPAD_GOAL1 1033
#define IDC_DEATH_POWERUP_USE2_IF_HAVE1_CHECK 1033
#define IDC_GREEN_CHECK 1033
#define IDC_ZOOM 1033
#define IDC_BFH_CHECK 1033
#define IDC_DEATH_BREAKS_APART 1033
#define IDC_AIN_LEFT 1033
#define IDC_FFT3_COMBO 1033
#define IDC_CHECK4 1034
#define IDC_COMBO21 1034
#define IDC_BUTTON25 1034
#define IDC_TRIG_ACTIV_ROBOT_WEAPONS 1034
#define IDC_AI_FLOCK_MEMBER_CHECK 1034
#define IDC_PHYSICS_IGNORE_ROBOTS_CHECK 1034
#define IDC_ROOMPAD_GOAL2 1034
#define IDC_SPAWNS_ROBOT_CHECK 1034
#define IDC_PROCEDURAL_CHECK 1034
#define IDC_GENERIC_DEATH_SPEW_2_IF_ZERO_1 1034
#define IDC_YELLOW_CHECK 1034
#define IDC_LEVEL_GOAL_SEC_GOAL_CHECK 1034
#define IDC_ONOFF 1034
#define IDC_DEATH_BLAST_RING 1034
#define IDC_AIN_FORWARD 1034
#define IDC_CHECK5 1035
#define IDC_BUTTON26 1035
#define IDC_CHECKIN_WEAPON 1035
#define IDC_TRIG_RENDER_FLOATING 1035
#define IDC_AI_DODGE_CHECK 1035
#define IDC_ROOMPAD_GOAL3 1035
#define IDC_METAL_CHECK 1035
#define IDC_COMBO23 1035
#define IDC_MAT_PROD_SOUND_COMBO 1035
#define IDC_GOAL_AUTO_COMPLETE_CHECK 1035
#define IDC_DEATH_FALLING_SMOKE 1035
#define IDC_PHYSICS_IGNORE_SAME_CHECK 1035
#define IDC_DEATH_DEBRIS_SMOKES 1035
#define IDC_AIN_BACK 1035
#define IDC_NSC_BUTTON 1035
#define IDC_CHECK6 1036
#define IDC_COMBO22 1036
#define IDC_BUTTON27 1036
#define IDC_PREV_WEAPON 1036
#define IDC_AI_AVOIDWALLS_CHECK 1036
#define IDC_ROOMPAD_GOAL4 1036
#define IDC_PLASTIC_CHECK 1036
#define IDC_DEATH_FALLING_DEBRIS 1036
#define IDC_PHYSICS_IGNORE_DOOR_CHECK 1036
#define IDC_TRIG_ACTIV_CLUTTER 1036
#define IDC_BUTTON28 1037
#define IDC_NEWTEXTUREEDIT 1037
#define IDC_MARBLE_CHECK 1037
#define IDC_COMBO24 1037
#define IDC_MAT_PROD_EFFECT_COMBO 1037
#define IDC_AI_AVOID_FRIENDS_CHECK 1037
#define IDC_BUTTON29 1038
#define IDC_MAT_PROD_TEXTURE_COMBO 1038
#define IDC_DEATH_REMAINS 1038
#define IDC_SMOOTH_SPEC_CHECK 1038
#define IDC_EDIT3 1039
#define IDC_BUTTON30 1039
#define IDC_PREV 1039
#define IDC_SHADOW_ROOM_EDIT 1039
#define IDC_GENERIC_INVEN_DESCRIPTION 1039
#define IDC_FOG_DENSITY 1039
#define IDC_ALTERNATE_CHANCE_EDIT 1039
#define IDC_MIN_VOLUME 1039
#define IDC_LEVEL_GOAL_LOC_NAME_EDIT 1039
#define IDC_DOOR_HITPOINTS_EDIT 1039
#define IDC_DEATH_LOSES_ANTIGRAV 1039
#define IDC_EDIT4 1040
#define IDC_BUTTON31 1040
#define IDC_NEXT_POWERUP 1040
#define IDC_SHADOW_FACE_EDIT 1040
#define IDC_GENERIC_INVEN_ICONNAME 1040
#define IDC_GRAVITY_TIME 1040
#define IDC_LEVEL_GOAL_PRIORITY_EDIT1 1040
#define IDC_AVOID_FRIENDS_DIST_EDIT 1040
#define IDC_GLOBAL_MULTIPLIER_EDIT 1040
#define IDC_SCROLLBAR1 1041
#define IDC_BUTTON33 1041
#define IDC_PREVIOUS 1041
#define IDC_GRAVITY_SIZE 1041
#define IDC_EDIT10 1041
#define IDC_LEVEL_GOAL_ITEM_EDIT 1041
#define IDC_SCRIPT_OVERRIDE 1041
#define IDC_ROOM_MULTIPLIER_EDIT 1041
#define IDC_FFT1_EDIT 1041
#define IDC_EDIT5 1042
#define IDC_BUTTON34 1042
#define IDC_NEXT 1042
#define IDC_RED_AMBIENT_EDIT 1042
#define IDC_LOD_DISTANCE_EDIT 1042
#define IDC_TERRIAN_DAMAGE_SIZE 1042
#define IDC_BRIEF_T_SPEED 1042
#define IDC_LEVEL_GOAL_DESC_EDIT 1042
#define IDC_BFHMIN_EDIT 1042
#define IDC_BUTTON35 1043
#define IDC_LOAD_DESTROYED 1043
#define IDC_GREEN_AMBIENT_EDIT 1043
#define IDC_TERRAIN_DAMAGE_DEPTH 1043
#define IDC_EDIT37 1043
#define IDC_LEVEL_GOAL_NAME_EDIT 1043
#define IDC_BFHMAX_EDIT 1043
#define IDC_DEATH_CONTACT_FIREBALL 1043
#define IDC_BUTTON36 1044
#define IDC_CHECK_ANIMATE 1044
#define IDC_BLUE_AMBIENT_EDIT 1044
#define IDC_RAMP_START 1044
#define IDC_LEVEL_GOAL_COMPLETION_EDIT 1044
#define IDC_BITMAP_NAME 1045
#define IDD_LITEPAD_DELTWEAK 1045
#define IDC_FOG_RED 1045
#define IDC_RAMP_END 1045
#define IDC_EDIT57 1045
#define IDC_DEATH_CONTACT_BLAST_RING 1045
#define IDC_DESTROY_NAME 1046
#define IDC_FOG_GREEN 1046
#define IDC_GEN_DURATION 1046
#define IDC_FFT2_EDIT 1046
#define IDC_EDIT11 1047
#define IDC_LOAD_BITMAP 1047
#define IDC_FOG_BLUE 1047
#define IDC_GEN_PERIOD 1047
#define IDC_GOAL_TABLE_EDIT 1047
#define IDC_RESPAWN_SCALAR_EDIT 1047
#define IDC_DEATH_DEBRIS_CONTACT_FIREBALL 1047
#define IDC_EDIT12 1048
#define IDC_TEX_LIST 1048
#define IDC_GEN_GAIN 1048
#define IDC_FIXED_FFT1_EDIT 1048
#define IDC_CHECK1 1049
#define IDC_EDIT13 1049
#define IDC_CHECK_TMAP2 1049
#define IDC_DEATH_DEBRIS_CONTACT_BLAST_RING 1049
#define IDC_FFT3_EDIT 1049
#define IDC_CHECK7 1050
#define IDC_DOORWAYPAD_EMPTY1 1050
#define IDC_DESTROY_PULLDOWN 1050
#define IDC_ROOM_AMGREEN 1050
#define IDC_CHECK8 1051
#define IDC_EFFECT_TEXTURE 1051
#define IDC_LEVEL_GOAL_ENABLED_CHECK 1051
#define IDC_L_Z_CHECK 1051
#define IDC_ROOM_AMRED 1051
#define IDC_ZMOVE_CHECK 1051
#define IDC_EDIT1 1052
#define IDC_EDIT33 1052
#define IDC_CHECK9 1052
#define IDC_GOALRED 1052
#define IDC_DOORDEACTIVATED 1052
#define IDC_PWIGGLE 1052
#define IDC_SLOPE_EDIT 1052
#define IDC_EDITNAME 1052
#define IDC_SCRIPTNAME 1052
#define IDC_X_GRANULAR_EDIT 1052
#define IDC_ANGLE_EDIT 1052
#define IDC_AI_HEARS_NOISE_DIST_EDIT 1052
#define IDC_ROBOT_FIRE0_START_TICK 1052
#define IDC_PARMEDIT1 1052
#define IDC_EXPLODE_SIZE_EDIT 1052
#define IDC_PATH_INC_TEXT 1052
#define IDC_AI_CIRCLE_DISTANCE_EDIT 1052
#define IDC_WB_FIRE0_START_TICK 1052
#define IDC_LEVEL_NAME 1052
#define IDC_BRIGHTNESS 1052
#define IDC_HUD_COCKPIT_TEXTURE 1052
#define IDC_TEXSCALE_EDIT 1052
#define IDC_PROC_RED_EDIT 1052
#define IDC_SHIP_ARMOR_EDIT 1052
#define IDC_TABLEEDIT_SCREEN_NAME_EDIT 1052
#define IDC_ASE_PROBABILITY 1052
#define IDC_ASP_MIN_DELAY 1052
#define IDC_FOV_EDIT 1052
#define IDC_LEVEL_GRAVITY_EDIT 1052
#define IDC_MAT_ATTACH_EDIT 1052
#define IDC_BRIEF_B_DESC 1052
#define IDC_STRINGEDIT 1052
#define IDC_ATTACK_LEVEL 1052
#define IDC_TABLEFILEFILTER_ADDNAME_EDIT 1052
#define IDC_MAX_AMMO 1052
#define IDC_SOUND_IMPORT_VOLUME_EDIT 1052
#define IDC_L_P_CHECK 1052
#define IDC_DAMAGE_PER_SEC_EDIT 1052
#define IDC_COMPILER_OUTPUT 1052
#define IDC_FILENAME 1052
#define IDC_COMPILER 1052
#define IDC_GENERIC_DATA_EDIT 1052
#define IDC_TEXT 1052
#define IDC_DEATH_DELAY_MIN 1052
#define IDC_MODULE 1052
#define IDC_DOORWAY_POS_EDIT 1052
#define IDC_ROOMPAD_DAMAGE 1052
#define IDC_OUTPUTFILE_EDIT 1052
#define IDC_BRIEF_BT_JUMP_SCREEN 1052
#define IDC_TERRAIN_SOUND_LOW_ALT 1052
#define IDC_VOLUME 1052
#define IDC_GENEREIC_DEATH_PROB1 1052
#define IDC_XPOS_EDIT 1052
#define IDC_EDIT2 1053
#define IDC_EDIT34 1053
#define IDC_CHECK22 1053
#define IDC_BLASTABLE 1053
#define IDC_PSTICKS 1053
#define IDC_Y_GRANULAR_EDIT 1053
#define IDC_START_ALPHA_EDIT 1053
#define IDC_AI_JOIN_BATTLES_DIST_EDIT 1053
#define IDC_GENERIC_IMPACT_SIZE_EDIT 1053
#define IDC_ROBOT_FIRE0_END_TICK 1053
#define IDC_PARMEDIT2 1053
#define IDC_EXPLODE_TIME_EDIT 1053
#define IDC_AI_MELEE1_DIST_EDIT 1053
#define IDC_WB_FIRE0_FIRE_TICK 1053
#define IDC_DESIGNER 1053
#define IDC_PROC_GREEN_EDIT 1053
#define IDC_ASE_MAX_VOLUME 1053
#define IDC_ASP_MAX_DELAY 1053
#define IDC_LEVEL_GOAL_PRIORITY_EDIT 1053
#define IDC_MAT_NUM_SPAWN_EDIT 1053
#define IDC_FADE_LEVEL 1053
#define IDC_L_H_CHECK 1053
#define IDC_FOG_SCALAR_EDIT 1053
#define IDC_AMB_N_GROUPS1 1053
#define IDC_OUTPUT 1053
#define IDC_N_FLAG1 1053
#define IDC_DEATH_DELAY_MAX 1053
#define IDC_NAME 1053
#define IDC_DOOR_BLASTABLE 1053
#define IDC_DOORWAY_HITPOINT_EDIT 1053
#define IDC_TEXTURE_AMBIENT_SOUND_VOLUME 1053
#define IDC_TERRAIN_SOUND_LOW_VOLUME 1053
#define IDC_GENEREIC_DEATH_PROB2 1053
#define IDC_AIN_MOVE_AMOUNT 1053
#define IDC_ZPOS_EDIT 1053
#define IDC_COMBO1 1054
#define IDC_EDIT14 1054
#define IDC_OPENED 1054
#define IDC_OBJECT_MASS_EDIT 1054
#define IDC_GREEN_LIGHTING 1054
#define IDC_PPERSISTENT 1054
#define IDC_SKY_BLUE_EDIT 1054
#define IDC_XZ_PLANE_ANGLE_EDIT 1054
#define IDC_RESOLUTION_EDIT 1054
#define IDC_GENERIC_IMPACT_DAMAGE_EDIT 1054
#define IDC_PARMEDIT3 1054
#define IDC_AI_NOTIFY_NEARWALL_CHECK 1054
#define IDC_PARTICLE_LIFE_EDIT 1054
#define IDC_NOTES 1054
#define IDC_PROC_BLUE_EDIT 1054
#define IDC_CHECK23 1054
#define IDC_LEVEL_GOAL_NLB_CHECK 1054
#define IDC_L_B_CHECK 1054
#define IDC_GENEREIC_DEATH_PROB3 1054
#define IDC_BUTTON16 1055
#define IDC_COMBO12 1055
#define IDC_EDIT15 1055
#define IDC_OBJ_SHOW_BOTS 1055
#define IDC_OBJECT_DRAG_EDIT 1055
#define IDC_BLUE_LIGHTING 1055
#define IDC_MEGA_HEIGHT_EDIT 1055
#define IDC_PUSESTHRUST 1055
#define IDC_HORIZON_RED_EDIT 1055
#define IDC_PITCH_ANGLE_EDIT 1055
#define IDC_AI_MAX_VEL_TIME_EDIT 1055
#define IDC_EDIT8 1055
#define IDC_GENERIC_IMPACT_TIME_EDIT 1055
#define IDC_ROBOT_FIRE0_START_TICK2 1055
#define IDC_PARMEDIT4 1055
#define IDC_WB_FIRE1_START_TICK 1055
#define IDC_PARTICLE_SIZE_EDIT 1055
#define IDC_CHECK24 1055
#define IDC_ATTACK_TIME 1055
#define IDC_LEVEL_GOAL_TLG_CHECK 1055
#define IDC_SWAP_DEST_COMBO 1055
#define IDC_ROTATE_SPEED_EDIT 1055
#define IDC_TERRAIN_SOUND_HIGH_VOLUME 1055
#define IDC_GENEREIC_DEATH_PROB4 1055
#define IDC_AIN_OTHER_NODE 1055
#define IDC_BUTTON18 1056
#define IDC_EDIT6 1056
#define IDC_EDIT27 1056
#define IDC_CHECKIN 1056
#define IDC_OBJ_SHOW_MINEDETAILS 1056
#define IDC_KEY1 1056
#define IDC_PGRAVITY 1056
#define IDC_FOG_RED_EDIT 1056
#define IDC_HEADING_ANGLE_EDIT 1056
#define IDC_AI_MAX_VELOCITY_EDIT 1056
#define IDC_ROBOT_FIRE0_END_TICK2 1056
#define IDC_WB_FIRE1_FIRE_TICK 1056
#define IDC_PARTICLE_COUNT_EDIT 1056
#define IDC_PROC_SIZE_EDIT 1056
#define IDC_DEATH_POWERUP1_NUM_EDIT 1056
#define IDC_BRIEF_COLOR_PAL 1056
#define IDC_FADE_TIME 1056
#define IDC_AMB_MIN1 1056
#define IDC_PITCH_EDIT 1056
#define IDC_BUTTON19 1057
#define IDC_EDIT7 1057
#define IDC_EDIT28 1057
#define IDC_LOCK 1057
#define IDC_OBJ_SHOW_POWERUPS 1057
#define IDC_DOOR_MODEL_NAME_EDIT 1057
#define IDC_KEY2 1057
#define IDC_PMAGNETISM 1057
#define IDC_HORIZON_BLUE_EDIT 1057
#define IDC_AI_MAX_TURN_RATE_EDIT 1057
#define IDC_ROBOT_FIRE0_START_TICK3 1057
#define IDC_LIGHT_MULTIPLY_EDIT 1057
#define IDC_WB_FIRE2_START_TICK 1057
#define IDC_COPYRIGHT 1057
#define IDC_PROC_FREQ_EDIT 1057
#define IDC_HOMING_FOV_TEXT 1057
#define IDC_DEATH_POWERUP1_PERCENT_EDIT 1057
#define IDC_AMB_MAX1 1057
#define IDC_BANK_EDIT 1057
#define IDC_BUTTON20 1058
#define IDC_EDIT16 1058
#define IDC_OBJ_SHOW_PLAYERS 1058
#define IDC_KEY3 1058
#define IDC_PWIND 1058
#define IDC_FOG_BLUE_EDIT 1058
#define IDC_EDIT9 1058
#define IDC_ROBOT_FIRE0_END_TICK3 1058
#define IDC_AI_NOTIFY_HITBYWEAPON_CHECK 1058
#define IDC_PULSE_TIME_EDIT 1058
#define IDC_WB_FIRE2_FIRE_TICK 1058
#define IDC_PROC_SPEED_EDIT 1058
#define IDC_DEATH_POWERUP2_NUM_EDIT 1058
#define IDC_BRIEF_T_LR_X 1058
#define IDC_MAT_SPAWN0_EDIT 1058
#define IDC_CUSTOM_SIZE_EDIT 1058
#define IDC_AMB_N_GROUPS2 1058
#define IDC_EDIT17 1059
#define IDC_CHECK10 1059
#define IDC_GOALBLUE 1059
#define IDC_KEY4 1059
#define IDC_WEAPON_MASS_EDIT 1059
#define IDC_ROBOT_FIRE_WEAPON_2_CHECK 1059
#define IDC_AI_FLOCK_ALIGNMENT_EDIT 1059
#define IDC_ROBOT_FIRE0_START_TICK4 1059
#define IDC_PULSE_OFFSET_EDIT 1059
#define IDC_WB_FIRE3_START_TICK 1059
#define IDC_LIGHT_TEXTURE 1059
#define IDC_PROC_HEAT_EDIT 1059
#define IDC_DEATH_POWERUP2_PERCENT_EDIT 1059
#define IDC_MAT_SPAWN2_EDIT 1059
#define IDC_AMB_MIN2 1059
#define IDC_EDIT18 1060
#define IDC_KEY5 1060
#define IDC_AI_FLOCK_SEPERATION_EDIT 1060
#define IDC_ROBOT_FIRE0_END_TICK4 1060
#define IDC_PARMEDIT5 1060
#define IDC_WB_FIRE3_FIRE_TICK 1060
#define IDC_MAT_SPAWN1_EDIT 1060
#define IDC_AMB_MAX2 1060
#define IDC_ROOM_AMBLUE 1060
#define IDC_EDIT19 1061
#define IDC_CHECK11 1061
#define IDC_GOALHOARD 1061
#define IDC_KEY6 1061
#define IDC_ROBOT_FIRE0_START_TICK5 1061
#define IDC_PARMEDIT6 1061
#define IDC_AI_NOTIFY_OBJFIRED_CHECK 1061
#define IDC_WB_FIRE4_START_TICK 1061
#define IDC_WATER_PROCEDURAL_CHECK 1061
#define IDC_MAT_SPAWN3_EDIT 1061
#define IDC_AMB_N_GROUPS3 1061
#define IDC_EDIT20 1062
#define IDC_CHECK12 1062
#define IDC_KEY7 1062
#define IDC_SKY_CHECK 1062
#define IDC_ROBOT_MELEE_1_CHECK 1062
#define IDC_WEAPON_FLASH_EDIT 1062
#define IDC_ROBOT_FIRE0_END_TICK5 1062
#define IDC_PARMEDIT7 1062
#define IDC_AI_NOTIFY_WEAPONHITPLAYER_CHECK 1062
#define IDC_WB_FIRE4_FIRE_TICK 1062
#define IDC_FORCE_LIGHTMAPS 1062
#define IDC_AMB_MIN3 1062
#define IDC_EDIT21 1063
#define IDC_BUTTON21 1063
#define IDC_OBJ_SHOW_MULTI 1063
#define IDC_ROBOT_MELEE_2_CHECK 1063
#define IDC_ROBOT_FIRE0_START_TICK6 1063
#define IDC_PARMEDIT8 1063
#define IDC_AI_MAX_TURN_RATE_TIME_EDIT 1063
#define IDC_WB_FIRE5_START_TICK 1063
#define IDC_MAT_PROD_0_QUATITY_EDIT 1063
#define IDC_AMB_MAX3 1063
#define IDC_EDIT22 1064
#define IDC_CHECK13 1064
#define IDC_MIRROR_CHECK 1064
#define IDC_ROBOT_FIRE0_END_TICK6 1064
#define IDC_AUTO_TURRETCONTROL_CHECK 1064
#define IDC_WB_FIRE5_FIRE_TICK 1064
#define IDC_MAT_PROD_1_QUATITY_EDIT 1064
#define IDC_AMB_N_GROUPS4 1064
#define IDC_IMPORT_4444 1064
#define IDC_EDIT23 1065
#define IDC_CHECK14 1065
#define IDC_DEATH_FROM_EDIT 1065
#define IDC_OBJECT_TEXTURE 1065
#define IDC_ROBOT_FIRE0_START_TICK7 1065
#define IDC_AI_FIREATTARGET_CHECK 1065
#define IDC_WB_FIRE6_START_TICK 1065
#define IDC_MAT_PROD_2_QUATITY_EDIT 1065
#define IDC_AMB_MIN4 1065
#define IDC_EDIT24 1066
#define IDC_DELETE 1066
#define IDC_DEATH_TO_EDIT 1066
#define IDC_ROBOT_FIRE0_END_TICK7 1066
#define IDC_AI_MAX_TURN_RATE_TIME_EDIT2 1066
#define IDC_AI_DODGE_VEL_PER_EDIT 1066
#define IDC_WB_FIRE6_FIRE_TICK 1066
#define IDC_AMB_MAX4 1066
#define IDC_EDIT25 1067
#define IDC_MISSILE1_CHECK 1067
#define IDC_ROBOT_FIRE0_START_TICK8 1067
#define IDC_AI_MAX_TURN_RATE_TIME_EDIT3 1067
#define IDC_AI_ATTACK_VEL_PER_EDIT 1067
#define IDC_WB_FIRE7_START_TICK 1067
#define IDC_AMB_N_GROUPS5 1067
#define IDC_EDIT26 1068
#define IDC_CHECK15 1068
#define IDC_PSHIP_ROT_THRUST_EDIT 1068
#define IDC_PSHIP_ROTTHRUST_EDIT 1068
#define IDC_MISSILE1_FROM_EDIT 1068
#define IDC_ROBOT_STAY_IN_OUT_CHECK 1068
#define IDC_TERRAIN_TEXTURE 1068
#define IDC_ROBOT_FIRE0_END_TICK8 1068
#define IDC_TAUNTATDEATH_CHECK 1068
#define IDC_WB_FIRE7_FIRE_TICK 1068
#define IDC_MAT_PROD_5_QUATITY_EDIT 1068
#define IDC_AMB_MIN5 1068
#define IDC_EDIT29 1069
#define IDC_CHECK16 1069
#define IDC_PSHIP_MAXTURNROLLRATE_EDIT 1069
#define IDC_WEAPON_ENERGY_USAGE_EDIT 1069
#define IDC_FLOOR_CHECK 1069
#define IDC_ROBOT_FIRE0_END_TICK9 1069
#define IDC_AI_FLINCH_CHECK 1069
#define IDC_WB_FIRE0_END_TICK 1069
#define IDC_MAT_PROD_6_QUATITY_EDIT 1069
#define IDC_AMB_MAX5 1069
#define IDC_4444_CHECK 1069
#define IDC_D_FLAG2 1069
#define IDC_EDIT32 1070
#define IDC_PSHIP_TURNROLLRATIO_EDIT 1070
#define IDC_MISSILE1_RECOIL_CHECK 1070
#define IDC_WEAPON_AMMO_USAGE_EDIT 1070
#define IDC_ROBOT_FIRE0_END_TICK10 1070
#define IDC_AI_MAX_TURN_RATE_TIME_EDIT4 1070
#define IDC_AI_FLEE_VEL_PER_EDIT 1070
#define IDC_WB_FIRE1_END_TICK 1070
#define IDC_MAT_PROD_7_QUATITY_EDIT 1070
#define IDC_AMB_N_GROUPS6 1070
#define IDC_S_FLAG2 1070
#define IDC_EDIT30 1071
#define IDC_EDIT35 1071
#define IDC_TEXTUREVIEW 1071
#define IDC_PSHIP_NAME_EDIT 1071
#define IDC_WEAPON_THRUST_TIME_EDIT 1071
#define IDC_ROBOT_FIRE0_END_TICK11 1071
#define IDC_AI_MELEE2_DIST_EDIT 1071
#define IDC_WB_FIRE2_END_TICK 1071
#define IDC_MAT_PROD_0_SEC_EDIT 1071
#define IDC_AMB_MIN6 1071
#define IDC_N_FLAG2 1071
#define IDC_EDIT31 1072
#define IDC_CHECK17 1072
#define IDC_PSHIP_MODEL_NAME_EDIT 1072
#define IDC_EDIT36 1072
#define IDC_RECOIL1_TO_EDIT 1072
#define IDC_CEILING_CHECK 1072
#define IDC_WEAPON_LIFE_TIME_EDIT 1072
#define IDC_ROBOT_FIRE0_END_TICK12 1072
#define IDC_AI_MELEE1_LATENCY_EDIT 1072
#define IDC_WB_FIRE3_END_TICK 1072
#define IDC_MAT_PROD_1_SEC_EDIT 1072
#define IDC_AMB_MAX6 1072
#define IDC_SATURATE_LIGHTMAP 1072
#define IDC_D_FLAG3 1072
#define IDC_CHECK18 1073
#define IDC_TEXURE_PASS_THRU_CHECK 1073
#define IDC_PSHIP_DYING_MODEL_NAME_EDIT 1073
#define IDC_ROBOT_FIRE0_END_TICK13 1073
#define IDC_AI_MELEE2_LATENCY_EDIT 1073
#define IDC_WB_FIRE4_END_TICK 1073
#define IDC_EDIT38 1073
#define IDC_MAT_PROD_2_SEC_EDIT 1073
#define IDC_S_FLAG3 1073
#define IDC_WEAPON_RECOIL_FORCE_EDIT 1073
#define IDC_LEVEL_CEILING_EDIT 1073
#define IDC_CHECK19 1074
#define IDC_MISSILE2_FROM_EDIT 1074
#define IDC_TEXTURE_FLY_THRU_CHECK 1074
#define IDC_ROBOT_FIRE0_END_TICK14 1074
#define IDC_WB_FIRE5_END_TICK 1074
#define IDC_PSHIP_COCKPIT_EDIT 1074
#define IDC_EDIT39 1074
#define IDC_MAT_PROD_3_SEC_EDIT 1074
#define IDC_N_FLAG3 1074
#define IDC_CHECK20 1075
#define IDC_MISSILE2_TO_EDIT 1075
#define IDC_MINE_TEXTURE 1075
#define IDC_ROBOT_FIRE0_END_TICK15 1075
#define IDC_WB_FIRE6_END_TICK 1075
#define IDC_EDIT40 1075
#define IDC_MAT_PROD_4_SEC_EDIT 1075
#define IDC_D_FLAG4 1075
#define IDC_CHECK21 1076
#define IDC_MISSILE2_RECOIL_CHECK 1076
#define IDC_TEXTURE_NO_COLLIDE_CHECK 1076
#define IDC_ROBOT_FIRE0_END_TICK16 1076
#define IDC_WB_FIRE7_END_TICK 1076
#define IDC_ROBOT_TEXTURE_CHECK 1076
#define IDC_EDIT41 1076
#define IDC_MAT_PROD_5_SEC_EDIT 1076
#define IDC_S_FLAG4 1076
#define IDC_RCS_STATUS 1077
#define IDC_RECOIL2_FROM_EDIT 1077
#define IDC_ROBOT_FIRE0_END_TICK17 1077
#define IDC_WB_FIRE0_CYCLE_TIME 1077
#define IDC_EDIT42 1077
#define IDC_MAT_PROD_6_SEC_EDIT 1077
#define IDC_N_FLAG4 1077
#define IDC_STATIC_MINASCII 1078
#define IDC_DESTROYVIEW 1078
#define IDC_RECOIL2_TO_EDIT 1078
#define IDC_ROBOT_FIRE0_END_TICK18 1078
#define IDC_WB_FIRE1_CYCLE_TIME 1078
#define IDC_EDIT43 1078
#define IDC_MAT_PROD_7_SEC_EDIT 1078
#define IDC_D_FLAG5 1078
#define IDC_STATIC_MAXASCII 1079
#define IDC_PALETTEVIEW 1079
#define IDC_MELEE1_CHECK 1079
#define IDC_ROBOT_FIRE0_END_TICK19 1079
#define IDC_WB_FIRE2_CYCLE_TIME 1079
#define IDC_BUMPVIEW 1079
#define IDC_EDIT44 1079
#define IDC_MAT_PROD_0_PRIORITY_EDIT 1079
#define IDC_S_FLAG5 1079
#define IDC_EDIT_MINASCII 1080
#define IDC_MELEE1_FROM_EDIT 1080
#define IDC_ROBOT_FIRE0_END_TICK20 1080
#define IDC_TEXTURE_GLOW 1080
#define IDC_WB_FIRE3_CYCLE_TIME 1080
#define IDC_EDIT45 1080
#define IDC_MAT_PROD_1_PRIORITY_EDIT 1080
#define IDC_N_FLAG5 1080
#define IDC_EDIT_MAXASCII 1081
#define IDC_MELEE1_TO_EDIT 1081
#define IDC_ROBOT_FIRE0_END_TICK21 1081
#define IDC_WB_FIRE4_CYCLE_TIME 1081
#define IDC_EDIT46 1081
#define IDC_MAT_PROD_2_PRIORITY_EDIT 1081
#define IDC_D_FLAG6 1081
#define IDC_STATIC_FONTVIEW 1082
#define IDC_MELEE1_RECOIL_CHECK 1082
#define IDC_ROBOT_FIRE0_END_TICK22 1082
#define IDC_WB_FIRE5_CYCLE_TIME 1082
#define IDC_EDIT47 1082
#define IDC_MAT_PROD_3_PRIORITY_EDIT 1082
#define IDC_S_FLAG6 1082
#define IDC_EDIT_FONTNAME 1083
#define IDC_MRECOIL1_FROM_EDIT 1083
#define IDC_ROBOT_FIRE0_END_TICK23 1083
#define IDC_WB_FIRE6_CYCLE_TIME 1083
#define IDC_EDIT48 1083
#define IDC_MAT_PROD_4_PRIORITY_EDIT 1083
#define IDC_N_FLAG6 1083
#define IDC_STATIC_FONTNAME 1084
#define IDC_MRECOIL1_TO_EDIT 1084
#define IDC_ROBOT_FIRE0_END_TICK24 1084
#define IDC_WB_FIRE7_CYCLE_TIME 1084
#define IDC_EDIT49 1084
#define IDC_MAT_PROD_5_PRIORITY_EDIT 1084
#define IDC_D_FLAG7 1084
#define IDC_OPEN 1085
#define IDC_MELEE2_CHECK 1085
#define IDC_EDIT50 1085
#define IDC_MAT_PROD_6_PRIORITY_EDIT 1085
#define IDC_S_FLAG7 1085
#define IDC_SAVE 1086
#define IDC_MELEE2_FROM_EDIT 1086
#define IDC_EDIT51 1086
#define IDC_MAT_PROD_7_PRIORITY_EDIT 1086
#define IDC_N_FLAG7 1086
#define IDC_SAVEAS 1087
#define IDC_MELEE2_TO_EDIT 1087
#define IDC_EDIT52 1087
#define IDC_MAX_OBJ_PROD_EDIT 1087
#define IDC_D_FLAG8 1087
#define IDC_NEW 1088
#define IDC_MELEE2_RECOIL_CHECK 1088
#define IDC_EDIT53 1088
#define IDC_PROD_RATE_MULTI_EDIT 1088
#define IDC_S_FLAG8 1088
#define IDC_VOLATILE 1089
#define IDC_MRECOIL2_FROM_EDIT 1089
#define IDC_EDIT54 1089
#define IDC_MAT_NUM_TYPES_EDIT 1089
#define IDC_N_FLAG8 1089
#define IDC_WATER 1090
#define IDC_MRECOIL2_TO_EDIT 1090
#define IDC_EDIT55 1090
#define IDC_MAX_ALIVE_CHILDREN_EDIT 1090
#define IDC_D_FLAG9 1090
#define IDC_FORCEFIELD 1091
#define IDC_IDLE_CHECK 1091
#define IDC_EDIT56 1091
#define IDC_MAT_EFFECT_PREPROD_TIME_EDIT 1091
#define IDC_S_FLAG9 1091
#define IDC_CHECK_DESTROY 1092
#define IDC_IDLE_FROM_EDIT 1092
#define IDC_MAT_EFFECT_POSTPROD_TIME_EDIT 1092
#define IDC_N_FLAG9 1092
#define IDC_IDLE_TO_EDIT 1093
#define IDC_D_FLAG10 1093
#define IDC_LAVA_CHECKBOX 1093
#define IDC_LIGHTING 1094
#define IDC_QUIRK_CHECK 1094
#define IDC_S_FLAG10 1094
#define IDC_RUBBLE_CHECKBOX 1094
#define IDC_REFLECT 1095
#define IDC_QUIRK_FROM_EDIT 1095
#define IDC_N_FLAG10 1095
#define IDC_DAMAGE 1096
#define IDC_QUIRK_TO_EDIT 1096
#define IDC_D_FLAG11 1096
#define IDC_SLIDEU 1097
#define IDC_FLINCH_CHECK 1097
#define IDC_S_FLAG11 1097
#define IDC_SLIDEV 1098
#define IDC_FLINCH_FROM_EDIT 1098
#define IDC_N_FLAG11 1098
#define IDC_STATIC_PROP 1099
#define IDC_FLINCH_TO_EDIT 1099
#define IDC_ALPHA_EDIT 1099
#define IDC_D_FLAG12 1099
#define IDC_TEX_STRING 1100
#define IDC_TAUNT_CHECK 1100
#define IDC_S_FLAG12 1100
#define IDC_TEX_NUM 1101
#define IDC_TAUNT_FROM_EDIT 1101
#define IDC_N_FLAG12 1101
#define IDC_FLOATING_KEYPAD_TAB 1102
#define IDC_TAUNT_TO_EDIT 1102
#define IDC_SPEED_EDIT 1102
#define IDC_D_FLAG13 1102
#define IDC_CHECK_MIPPED 1103
#define IDC_SPECIAL1_CHECK 1103
#define IDC_S_FLAG13 1103
#define IDC_ADD_NEW_POWERUP 1104
#define IDC_SPECIAL1_FROM_EDIT 1104
#define IDC_N_FLAG13 1104
#define IDC_CHECK_BREAKABLE 1104
#define IDC_POWER_NAME_EDIT 1105
#define IDC_SPECIAL1_TO_EDIT 1105
#define IDC_D_FLAG14 1105
#define IDC_DELETE_POWERUP 1106
#define IDC_SPECIAL2_FROM_EDIT 1106
#define IDC_S_FLAG14 1106
#define IDC_LOCK_POWERUP 1107
#define IDC_SPECIAL2_TO_EDIT 1107
#define IDC_N_FLAG14 1107
#define IDC_POWERUPS_OUT 1108
#define IDC_SPECIAL3_FROM_EDIT 1108
#define IDC_D_FLAG15 1108
#define IDC_RED_SLIDER 1109
#define IDC_SPECIAL3_TO_EDIT 1109
#define IDC_S_FLAG15 1109
#define IDC_GREEN_SLIDER 1110
#define IDC_SPECIAL5_CHECK 1110
#define IDC_N_FLAG15 1110
#define IDC_BLUE_SLIDER 1111
#define IDC_SPECIAL4_FROM_EDIT 1111
#define IDC_D_FLAG16 1111
#define IDC_MONO_SLIDER 1112
#define IDC_SPECIAL4_TO_EDIT 1112
#define IDC_S_FLAG16 1112
#define IDC_RGB_COLOR_VIEW 1113
#define IDC_SPECIAL4_CHECK 1113
#define IDC_N_FLAG16 1113
#define IDC_MONO_COLOR_VIEW 1114
#define IDC_SPECIAL5_FROM_EDIT 1114
#define IDC_D_FLAG17 1114
#define IDC_LOAD_MODEL 1115
#define IDC_LOAD_IMAGE 1115
#define IDC_SPECIAL5_TO_EDIT 1115
#define IDC_S_FLAG17 1115
#define IDC_ANIMATION 1116
#define IDC_STANDING_FROM_EDIT 1116
#define IDC_POWERUP_AMBIENT_SOUND_LIST 1116
#define IDC_N_FLAG17 1116
#define IDC_POWER_MODEL_EDIT 1117
#define IDC_POWER_IMAGE_EDIT 1117
#define IDC_STANDING_TO_EDIT 1117
#define IDC_D_FLAG18 1117
#define IDC_POWER_ANIM_EDIT 1118
#define IDC_FLYING_FROM_EDIT 1118
#define IDC_S_FLAG18 1118
#define IDC_POWER_PULLDOWN 1119
#define IDC_FLYING_TO_EDIT 1119
#define IDC_N_FLAG18 1119
#define IDC_POWERVIEW 1120
#define IDC_POWERUPVIEW 1120
#define IDC_ROLLING_FROM_EDIT 1120
#define IDC_D_FLAG19 1120
#define IDC_USE_MODEL 1121
#define IDC_ROLLING_TO_EDIT 1121
#define IDC_S_FLAG19 1121
#define IDC_PICKUP_SOUND 1122
#define IDC_WALKING_FROM_EDIT 1122
#define IDC_POWERUP_PICKUP_SOUND_LIST 1122
#define IDC_N_FLAG19 1122
#define IDC_AMBIENT_SOUND 1123
#define IDC_WALKING_TO_EDIT 1123
#define IDC_POWERUP_BOUNCE_SOUND_LIST 1123
#define IDC_D_FLAG20 1123
#define IDC_ADD_INVENTORY 1124
#define IDC_JUMPING_FROM_EDIT 1124
#define IDC_S_FLAG20 1124
#define IDC_WINDOWED 1125
#define IDC_JUMPING_TO_EDIT 1125
#define IDC_N_FLAG20 1125
#define IDC_DESTROY_PALLETIZED 1126
#define IDC_D_FLAG21 1126
#define IDC_S_FLAG21 1127
#define IDC_PREV_PAL 1128
#define IDC_GP_MASK_0_0 1128
#define IDC_N_FLAG21 1128
#define IDC_NEXT_PAL 1129
#define IDC_GP_MASK_0_1 1129
#define IDC_D_FLAG22 1129
#define IDC_ADD_SOUND 1130
#define IDC_GP_MASK_0_2 1130
#define IDC_S_FLAG22 1130
#define IDC_DELETE_SOUND 1131
#define IDC_GP_MASK_0_3 1131
#define IDC_N_FLAG22 1131
#define IDC_CHECKIN_SOUND 1132
#define IDC_GP_MASK_0_4 1132
#define IDC_D_FLAG23 1132
#define IDC_LOCK_SOUND 1133
#define IDC_GP_MASK_0_5 1133
#define IDC_S_FLAG23 1133
#define IDC_PREV_SOUND 1134
#define IDC_GP_MASK_0_6 1134
#define IDC_N_FLAG23 1134
#define IDC_NEXT_SOUND 1135
#define IDC_GP_MASK_0_7 1135
#define IDC_D_FLAG24 1135
#define IDC_PLAYSOUND 1136
#define IDC_GP_MASK_1_0 1136
#define IDC_S_FLAG24 1136
#define IDC_SOUND_NAME 1137
#define IDC_SOUND_NAME_EDIT 1137
#define IDC_GP_MASK_1_1 1137
#define IDC_N_FLAG24 1137
#define IDC_RAW_NAME 1138
#define IDC_RAW_NAME_EDIT 1138
#define IDC_GP_MASK_1_2 1138
#define IDC_D_FLAG25 1138
#define IDC_SOUNDTYPE 1139
#define IDC_SOUNDTYPE_LIST 1139
#define IDC_GP_MASK_1_3 1139
#define IDC_S_FLAG25 1139
#define IDC_SOUND_IDS 1140
#define IDC_SOUND_PULLDOWN 1140
#define IDC_GP_MASK_1_4 1140
#define IDC_N_FLAG25 1140
#define IDC_PAL_STATIC 1141
#define IDC_GP_MASK_1_5 1141
#define IDC_KILLSOUNDS 1141
#define IDC_D_FLAG26 1141
#define IDC_HOGLIST 1142
#define IDC_GP_MASK_1_6 1142
#define IDC_S_FLAG26 1142
#define IDC_HOGPROGRESS 1143
#define IDC_GP_MASK_1_7 1143
#define IDC_N_FLAG26 1143
#define IDC_STATUSTEXT 1144
#define IDC_GP_MASK_2_0 1144
#define IDC_D_FLAG27 1144
#define IDC_TEXTURE_UP 1145
#define IDC_GP_MASK_2_1 1145
#define IDC_S_FLAG27 1145
#define IDC_TEXTURE_DOWN 1146
#define IDC_GP_MASK_2_2 1146
#define IDC_N_FLAG27 1146
#define IDC_TEXTURE_LEFT 1147
#define IDC_GP_MASK_2_3 1147
#define IDC_D_FLAG28 1147
#define IDC_TEXTURE_RIGHT 1148
#define IDC_GP_MASK_2_4 1148
#define IDC_S_FLAG28 1148
#define IDC_TEXTURE_CURRENT 1149
#define IDC_GP_MASK_2_5 1149
#define IDC_N_FLAG28 1149
#define IDC_OBJPAD_MOVEFORWARD 1150
#define IDC_GP_MASK_2_6 1150
#define IDC_D_FLAG29 1150
#define IDC_OBJPAD_MOVERIGHT 1151
#define IDC_GP_MASK_2_7 1151
#define IDC_S_FLAG29 1151
#define IDC_OBJPAD_MOVELEFT 1152
#define IDC_GP_MASK_3_0 1152
#define IDC_N_FLAG29 1152
#define IDC_OBJPAD_TOGGLEMOVEMENT 1153
#define IDC_GP_MASK_3_1 1153
#define IDC_D_FLAG30 1153
#define IDC_OBJPAD_DROPOBJ 1154
#define IDC_GP_MASK_3_2 1154
#define IDC_S_FLAG30 1154
#define IDC_OBJPAD_NEXTOBJ 1155
#define IDC_GP_MASK_3_3 1155
#define IDC_N_FLAG30 1155
#define IDC_OBJPAD_DECHEADING 1156
#define IDC_GP_MASK_3_4 1156
#define IDC_D_FLAG31 1156
#define IDC_OBJPAD_INCHEADING 1157
#define IDC_GP_MASK_3_5 1157
#define IDC_S_FLAG31 1157
#define IDC_OBJPAD_INCPITCH 1158
#define IDC_GP_MASK_3_6 1158
#define IDC_N_FLAG31 1158
#define IDC_OBJPAD_DECBANK 1159
#define IDC_GP_MASK_3_7 1159
#define IDC_D_FLAG32 1159
#define IDC_OBJPAD_INCBANK 1160
#define IDC_GP_MASK_4_0 1160
#define IDC_S_FLAG32 1160
#define IDC_OBJPAD_DECPITCH 1161
#define IDC_GP_MASK_4_1 1161
#define IDC_N_FLAG32 1161
#define IDC_OBJPAD_PLACEOBJ 1162
#define IDC_GP_MASK_4_2 1162
#define IDC_OBJ_DELOBJ 1163
#define IDC_GP_MASK_4_3 1163
#define IDC_OBJPAD_MOVEBACK 1164
#define IDC_GP_MASK_4_4 1164
#define IDC_OBJPAD_DELETEALL 1164
#define IDC_OBJPAD_MOVEUP 1165
#define IDC_GP_MASK_4_5 1165
#define IDC_OBJPAD_MOVEDOWN 1166
#define IDC_GP_MASK_4_6 1166
#define IDC_POWERUP_SIZE_EDIT 1167
#define IDC_GP_MASK_4_7 1167
#define IDC_POW_SCORE_EDIT 1168
#define IDC_GP_MASK_5_0 1168
#define IDC_POW_MASS_EDIT 1169
#define IDC_GP_MASK_5_1 1169
#define IDC_POW_DRAG_EDIT 1170
#define IDC_GP_MASK_5_2 1170
#define IDC_COMBO_OBJTYPE 1171
#define IDC_GP_MASK_5_3 1171
#define IDC_COMBO_OBJID 1172
#define IDC_GP_MASK_5_4 1172
#define IDC_TEXLIST_VERT 1173
#define IDC_GP_MASK_5_5 1173
#define IDC_GP_MASK_5_6 1174
#define IDC_TEXPAD_SLIDERIGHT 1175
#define IDC_GP_MASK_5_7 1175
#define IDC_TEXPAD_SLIDEUP 1176
#define IDC_GP_MASK_6_0 1176
#define IDC_TEXPAD_SLIDEDOWN 1177
#define IDC_GP_MASK_6_1 1177
#define IDC_TEXPAD_ROTLEFT 1178
#define IDC_GP_MASK_6_2 1178
#define IDC_TEXPAD_ROTRIGHT 1179
#define IDC_GP_MASK_6_3 1179
#define IDC_TEXPAD_STRETCHLESS 1180
#define IDC_GP_MASK_6_4 1180
#define IDC_TEXPAD_STRETCHMORE 1181
#define IDC_GP_MASK_6_5 1181
#define IDC_TEXTURE_SCROLL 1182
#define IDC_GP_MASK_6_6 1182
#define IDC_TEXPAD_EXPAND_U 1182
#define IDC_GP_MASK_6_7 1183
#define IDC_TEXPAD_EXPAND_V 1183
#define IDC_GP_MASK_7_0 1184
#define IDC_TEXPAD_CONTRACT_U 1184
#define IDC_GP_MASK_7_1 1185
#define IDC_TEXPAD_CONTRACT_V 1185
#define IDC_GP_MASK_7_2 1186
#define IDC_GP_MASK_7_3 1187
#define IDC_GP_MASK_7_4 1188
#define IDC_GP_MASK_7_5 1189
#define IDC_GP_MASK_7_6 1190
#define IDC_GP_MASK_7_7 1191
#define IDC_GP_MASK_Q_0 1192
#define IDC_GB_MASK_LATENCY_1_EDIT 1193
#define IDC_GB_MASK_LATENCY_2_EDIT 1194
#define IDC_GB_MASK_LATENCY_3_EDIT 1195
#define IDC_GB_MASK_LATENCY_4_EDIT 1196
#define IDC_GB_MASK_LATENCY_5_EDIT 1197
#define IDC_GB_MASK_LATENCY_6_EDIT 1198
#define IDC_GB_MASK_LATENCY_7_EDIT 1199
#define IDC_TURRET_SPEED_EDIT 1200
#define IDC_GP_MASK_Q_1 1200
#define IDC_GP_MASK_Q_2 1201
#define IDC_GP_MASK_Q_3 1202
#define IDC_GP_MASK_Q_4 1203
#define IDC_GP_MASK_Q_5 1204
#define IDC_GP_MASK_Q_6 1205
#define IDC_GP_MASK_Q_7 1206
#define IDC_OBJECTPAD_GROUP 1214
#define IDC_OBJECT_OPTIONS_GROUP 1217
#define IDC_OBJECT_GROUP 1218
#define IDC_OBJECT_CONTAINS_GROUP 1219
#define IDC_OBJ_PREVIEW 1220
#define IDC_TEXPAD_REMAPT1 1221
#define IDC_TEXPAD_FLIPX 1222
#define IDC_TEXPAD_FLIPY 1223
#define IDC_TEXPAD_REMAPT2 1224
#define IDC_TEXPAD_TMAP1 1225
#define IDC_TEXPAD_GRAB 1226
#define IDC_TEXPAD_ROTATE90 1227
#define IDC_TEXPAD_NEXTEDGE 1228
#define IDC_TEXPAD_SETDEFAULT 1229
#define IDC_LITEPAD_SMOOTHSIDE 1230
#define IDC_LITEPAD_SMOOTHALL 1231
#define IDC_LITEPAD_QUICKALL 1232
#define IDC_LITEPAD_DEC_VERTEX 1233
#define IDC_LITEPAD_INC_VERTEX 1234
#define IDC_LITEPAD_DEC_SIDE 1235
#define IDC_LITEPAD_SETDEFAULT 1236
#define IDC_LITEPAD_INC_SIDE 1237
#define IDC_LITEPAD_DEC_EDGE 1238
#define IDC_LITEPAD_INC_EDGE 1239
#define IDC_LITEPAD_PROTECTTWEAK 1240
#define IDC_LITEPAD_NEXTEDGE 1241
#define IDC_LITEPAD_NEXTVERTEX 1242
#define IDC_LIGHTING_GROUP 1243
#define IDC_LITE_COPY 1244
#define IDC_LITE_PASTE 1245
#define IDC_LITEPAD_EMPTY 1246
#define IDC_LITEPAD_TERRAIN_RADIOSITY 1246
#define IDC_LITEPAD_EMPTY1 1247
#define IDC_LITEPAD_EMPTY2 1248
#define IDC_LITEPAD_COUNT_LIGHTS 1248
#define IDC_LIGHTPAD_GROUP 1249
#define IDC_OBJ_SCROLL 1250
#define IDC_OBJ_PALETTE 1251
#define IDC_OBJPAD_FLIPOBJ 1252
#define IDC_OBJPAD_PROPERTIES 1253
#define IDC_PLAYPAD_ADDCOOP 1254
#define IDC_PLAYPAD_ADDMULTI 1255
#define IDC_OBJPAD_SETDEFAULT 1256
#define IDC_PLAYPAD_EMPTY2 1257
#define IDC_PLAYPAD_EMPTY3 1258
#define IDC_PATH_MOVE_NODE_TO_CURRENT_OBJECT 1258
#define IDC_PLAYPAD_EMPTY4 1259
#define IDC_PATH_MOVE_OBJECT_BUTTON 1259
#define IDC_PLAYPAD_EMPTY5 1260
#define IDC_PLAYPAD_EMPTY6 1261
#define IDC_PLAYPAD_EMPTY7 1262
#define IDC_PLAYPAD_EMPTY8 1263
#define IDC_PLAYPAD_EMPTY9 1264
#define IDC_PATH_VERIFY_BUTTON 1264
#define IDC_PLAYPAD_EMPTY10 1265
#define IDC_PLAYPAD_EMPTY11 1266
#define IDC_PATH_MOVE_OBJ_NO_ORIENT 1266
#define IDC_PLAYPAD_EMPTY12 1267
#define IDC_PLAYPAD_EMPTY13 1268
#define IDC_PLAYPAD_EMPTY14 1269
#define IDC_PLAYPAD_EMPTY15 1270
#define IDC_PATH_REORIENT_VIEWER_BUTTON 1270
#define IDC_CURVEPAD_SETCURVE 1272
#define IDC_CURVEPAD_SMOOTHMORPH 1273
#define IDC_CURVEPAD_ENDFLOATING 1274
#define IDC_CURVEPAD_INCR1 1275
#define IDC_CURVEPAD_DECR1 1276
#define IDC_CURVEPAD_INCR4 1277
#define IDC_CURVEPAD_DECR4 1278
#define IDC_CURVEPAD_ADDTOMARKED 1279
#define IDC_CURVEPAD_ADDTOEND 1280
#define IDC_CURVEPAD_KEEP_XSECTION 1281
#define IDC_CURVEPAD_DELCURVE 1282
#define IDC_CURVEPAD_CREATECURVE 1283
#define IDC_CURVEPAD_ADDSEG 1284
#define IDC_CURVEPAD_EMPTY1 1285
#define IDC_CURVEPAD_EMPTY2 1286
#define IDC_CURVEPAD_EMPTY3 1287
#define IDC_CURVEPAD_EMPTY4 1288
#define IDC_TRIGGERPAD_GROUP 1289
#define IDC_TRIGGER_BINDMATCEN 1290
#define IDC_TRIGGER_BINDOBJ 1291
#define IDC_TRIGGER_PREVTRIGGER 1292
#define IDC_TRIGGER_NEXTTRIGGER 1293
#define IDC_TRIGGER_SUPRESSMESAGE 1294
#define IDC_TRIGGER_ONESHOT 1295
#define IDC_TRIGGER_LIGHTOFF 1296
#define IDC_RADIO16 1297
#define IDC_RADIO17 1298
#define IDC_TRIGGER_ADDTRIGGER 1299
#define IDC_DOORWAYPAD_GROUP 1300
#define IDC_DOORWAY_GROUP 1301
#define IDC_TRIGGER_EMPTY8 1302
#define IDC_TRIGGERPAD_EMPTY1 1303
#define IDC_TRIGGERPAD_EMPTY2 1304
#define IDC_TRIGGERPAD_EMPTY3 1305
#define IDC_TRIGGERPAD_EMPTY4 1306
#define IDC_TRIGGERPAD_EMPTY5 1307
#define IDC_TRIGGERPAD_EMPTY6 1308
#define IDC_TRIGGERPAD_EMPTY7 1309
#define IDC_TRIGGERPAD_EMPTY9 1310
#define IDC_TRIGGERPAD_EMPTY10 1311
#define IDC_TRIGGERPAD_EMPTY11 1312
#define IDC_TRIGGERPAD_EMPTY12 1313
#define IDC_TRIGGERPAD_EMPTY13 1314
#define IDC_TRIGGERPAD_EMPTY14 1315
#define IDC_TRIGGERPAD_EMPTY15 1316
#define IDC_TRIGGERPAD_EMPTY16 1317
#define IDC_TRIGGERPAD_EMPTY17 1318
#define IDC_DOORWAY_DOORPREV 1319
#define IDC_DOORWAY_AUTO 1320
#define IDC_DOORWAY_ILLUSIONOFF 1321
#define IDC_DOORWAY_KEY 1322
#define IDC_DOORWAY_BUDDYPROOF 1323
#define IDC_DOORWAY_ADDDOORWAY 1324
#define IDC_DOORWAY_PLACEDOOR 1324
#define IDC_DOORWAY_REMOVEDOORWAY 1325
#define IDC_DOORWAY_ATTACHDOOR 1325
#define IDC_DOORWAY_BINDCONTROL 1326
#define IDC_DOORWAY_BINDTO 1326
#define IDC_DOORWAY_BINDOBJECT 1327
#define IDC_DOORWAY_MOVE 1327
#define IDC_DOORWAY_GOTODOOR 1328
#define IDC_DOORWAY_CLIPSTATIC 1330
#define IDC_DOORWAY_EMPTY8 1331
#define IDC_DOORWAYPAD_EMPTY9 1332
#define IDC_DOORWAY_EMPTY15 1333
#define IDC_DOORWAYPAD_EMPTY16 1334
#define IDC_TRIGGER_GROUP 1335
#define IDC_TRIGGERTYPE 1336
#define IDC_TRIGGERNUMSPIN 1338
#define IDC_TRIGGERNUM 1339
#define IDC_BINDINGSLIST 1340
#define IDC_SIDETEXT 1341
#define IDC_DOORS_OUT 1343
#define IDC_ADD_DOOR 1344
#define IDC_DELETE_DOOR 1345
#define IDC_LOCK_DOOR 1346
#define IDC_CHECKIN_DOOR 1347
#define IDC_DOOR_PREV 1348
#define IDC_DOOR_NEXT 1349
#define IDC_LOAD_DOOR_MODEL 1351
#define IDC_DOOR_OPEN_SOUND 1352
#define IDC_DOOR_OPEN_TIME 1353
#define IDC_DOOR_STAYS_OPEN 1354
#define IDC_DOOR_CLOSE_TIME 1355
#define IDC_DOOR_CLOSE_SOUND 1355
#define IDC_CLOSE_TIME 1356
#define IDC_DOOR_ENERGY_SOUND 1357
#define IDC_DOOR_MATERIAL_SOUND 1358
#define IDC_DOORVIEW 1359
#define IDC_MOVETOSEGSIDE 1360
#define IDC_GOTOTRIG 1361
#define IDC_GOTOBINDING 1362
#define IDC_DOORIDSPIN 1363
#define IDC_DOORID 1364
#define IDC_AUTODOOR 1365
#define IDC_DOORLOCKED 1366
#define IDC_KEY0 1367
#define IDC_DOORPIC 1368
#define IDC_DOORSCROLL 1369
#define IDC_DOORSELSPIN 1369
#define IDC_SIDENUMTEXT 1371
#define IDC_BINDINGTEXT 1372
#define IDC_DOOR_PULLDOWN 1373
#define IDC_EMPTY1 1377
#define IDC_TERRPAD_PYRAMID 1377
#define IDC_EMPTY2 1378
#define IDC_TERRPAD_HILL 1378
#define IDC_TERRPAD_IMPORT 1379
#define IDC_TERRPAD_MOVE_UP 1380
#define IDC_TERRPAD_MOVE_DOWN 1381
#define IDC_TERRPAD_RENORMALIZE 1382
#define IDC_TERRPAD_RAISE10 1383
#define IDC_TERRPAD_LOWER10 1384
#define IDC_DOORWAYSELEDIT 1385
#define IDC_ROBOT_NAME_EDIT 1386
#define IDC_ROBOT_MODEL 1387
#define IDC_ADD_NEW_ROBOT 1388
#define IDC_DELETE_ROBOT 1389
#define IDC_LOCK_ROBOT 1390
#define IDC_CHECKIN_ROBOT 1391
#define IDC_PREV_ROBOT 1392
#define IDC_NEXT_ROBOT 1393
#define IDC_ROBOT_MODEL_NAME_EDIT 1394
#define IDC_ROBOTVIEW 1395
#define IDC_SKY_TEXTURE 1397
#define IDC_GRAVITY_CHECK 1399
#define IDC_MAGNETISM_CHECK 1400
#define IDC_WIND_CHECK 1401
#define IDC_TERRPAD_ROT_TEXTURE 1402
#define IDC_TERRPAD_SELECT_NONE 1403
#define IDC_SKY_NEARER 1404
#define IDC_SKY_FARTHER 1405
#define IDC_POPULAR_PALETTE 1406
#define IDC_STARS_CHECK 1407
#define IDC_ROBOT_MASS_EDIT 1408
#define IDC_SATELLITE_CHECK 1408
#define IDC_ROBOT_DRAG_EDIT 1409
#define IDC_ROBOT_MAX_SPEED_EDIT 1410
#define IDC_ROBOT_SIZE_EDIT 1411
#define IDC_PSHIP_PREV 1411
#define IDC_PSHIP_CHECKIN 1412
#define IDC_PSHIP_LOCK 1413
#define IDC_PSHIP_DELETE 1414
#define IDC_ADD_PSHIP 1415
#define IDC_PSHIPS_OUT 1416
#define IDC_PSHIP_LOAD_MODEL 1417
#define IDC_PSHIP_MASS_EDIT 1418
#define IDC_PSHIP_DYING_MODEL 1418
#define IDC_PSHIP_DRAG_EDIT 1419
#define IDC_PSHIP_COCKPIT 1419
#define IDC_PSHIP_WIGGLE_EDIT 1420
#define IDC_PSHIP_MAX_THRUST_EDIT 1421
#define IDC_PSHIP_PULLDOWN 1422
#define IDC_SHIPVIEW 1423
#define IDC_ADD_WEAPON 1424
#define IDC_PSHIP_ROTDRAG_EDIT 1424
#define IDC_DELETE_WEAPON 1425
#define IDC_PSHIP_WIGGLEFREQ_EDIT 1425
#define IDC_LOCK_WEAPON 1426
#define IDC_NEXT_WEAPON 1427
#define IDC_WEAPON_NAME_EDIT 1428
#define IDC_WEAPON_PULLDOWN 1429
#define IDC_WEAPON_DRAG_EDIT 1430
#define IDC_WEAPON_WALL_VCLIP 1431
#define IDC_WEAPON_WALL_VCLIP_EDIT 1432
#define IDC_WEAPON_ROBOT_CHECK 1433
#define IDC_WEAPON_PLAYER_CHECK 1434
#define IDC_LOAD_WEAPON_ANIM 1435
#define IDC_WEAPON_VCLIP_EDIT 1436
#define IDC_WEAPONVIEW 1437
#define IDC_TRANSPARENCY 1438
#define IDC_WEAPONFIREVIEW 1438
#define IDC_PSHIP_MAGNETISM_CHECK 1439
#define IDC_LOAD_WEAPON_DISCHARGE 1439
#define IDC_PSHIP_WIND_CHECK 1440
#define IDC_WEAPON_DISCHARGE_EDIT 1440
#define IDC_PATHPAD_ADD_PATH 1441
#define IDC_WEAPON_DRAG_EDIT2 1441
#define IDC_WEAPON_ROT_DRAG_EDIT 1441
#define IDC_PATHPAD_MOVE_FORWARD 1442
#define IDC_PATHPAD_MOVE_BACKWARD 1443
#define IDC_PATHPAD_MOVE_LEFT 1444
#define IDC_PATHPAD_MOVE_RIGHT 1445
#define IDC_PATHPAD_PREV_NODE 1446
#define IDC_PATHPAD_INSERT_NODE 1447
#define IDC_PATHPAD_DELETE_NODE 1448
#define IDC_PATHPAD_NUM_NODES 1449
#define IDC_PATHPAD_PULLDOWN 1450
#define IDC_CURRENT_NODE_EDIT 1451
#define IDC_PATHPAD_MOVE_UP 1452
#define IDC_PATHPAD_MOVE_DOWN 1453
#define IDC_PATHPAD_CENTER_VIEW 1454
#define IDC_PATHPAD_NEXT_NODE 1455
#define IDC_EDIT 1456
#define IDC_PATHPAD_CUR_NODE_ROOM 1456
#define IDC_DELETE_PATH 1457
#define IDC_SHOW_NODES_CHECK 1458
#define IDC_FAST_TERRAIN_CHECK 1459
#define IDC_PSHIP_MAXVEL_STATIC 1461
#define IDC_PSHIP_MAXRPS_STATIC 1462
#define IDC_POWERUP_WIGGLE_CHECK 1463
#define IDC_POWERUP_WIGGLE_EDIT 1464
#define IDC_POWERUP_WIGGLEFREQ_EDIT 1465
#define IDC_TERRPAD_REDO_TOPMAP 1466
#define IDC_TERRPAD_FILL_AREA 1467
#define IDC_TERRPAD_MAKE_ZERO 1468
#define IDC_TERRPAD_MAKE_MIN 1469
#define IDC_TERRPAD_MAKE_MAX 1470
#define IDC_TERRPAD_PANCAKES 1471
#define IDC_OBJECT_NAME 1472
#define IDC_OBJECT_TYPE 1473
#define IDC_OBJECT_SIZE 1474
#define IDC_OBJECT_MASS 1475
#define IDC_OBJECT_DRAG 1476
#define IDC_OBJECT_SIZE_EDIT 1477
#define IDC_OBJECT_NAME_EDIT 1478
#define IDC_OBJECT_TYPE_EDIT 1479
#define IDC_WEAPON_HUDVIEW 1480
#define IDC_WEAPON_FIRE_VIEW 1481
#define IDC_WEAPON_SPEED_EDIT 1482
#define IDC_WEAPON_THRUST_EDIT 1482
#define IDC_TERR_LIGHT_COUNTER 1483
#define IDC_WEAPON_INIT_VELOCITY_EDIT 1483
#define IDC_TERR_LIGHT_CLOCK 1484
#define IDC_WEAPON_MAX_BOUNCES_EDIT 1484
#define IDC_WEAPON_SPEED_EDIT2 1485
#define IDC_WEAPON_FULL_ROT_THRUST_EDIT 1485
#define IDC_WEAPON_INIT_VELOCITY_EDIT2 1486
#define IDC_WEAPON_INIT_ROT_VELOCITY_X_EDIT 1486
#define IDC_WEAPON_PERCENT_LOSS_EDIT 1487
#define IDC_TERR_MOVE_MOON 1488
#define IDC_WEAPON_INIT_ROT_VELOCITY_Y_EDIT3 1488
#define IDC_TERR_RANDOMIZE_SKY 1489
#define IDC_WEAPON_INIT_ROT_VELOCITY_Z_EDIT4 1489
#define IDC_NUM_MOONS_STATIC 1490
#define IDC_WEAPON_DAMAGE_EDIT 1490
#define IDC_TERR_LESS_MOONS 1491
#define IDC_WEAPON_GENERIC_DAMAGE_EDIT 1491
#define IDC_TERR_PREV_MOON 1492
#define IDC_CUR_MOON_STATIC 1493
#define IDC_WEAPON_GRAVITY_CHECK 1494
#define IDC_TERR_MOVE_MOON_AWAY 1494
#define IDC_WEAPON_MAGNETISM_CHECK 1495
#define IDC_WEAPON_BOUNCY_CHECK 1496
#define IDC_WEAPON_THRUSTS_CHECK 1497
#define IDC_WEAPON_WIGGLES_CHECK 1498
#define IDC_WEAPON_WIGGLE_AMP_EDIT 1499
#define IDC_WEAPON_WIGGLE_FREQ_EDIT 1500
#define IDC_ALERT_CHECK 1501
#define IDC_DEATH_CHECK 1502
#define IDC_MISSILE2_CHECK 1503
#define IDC_SPECIAL2_CHECK 1504
#define IDC_SPECIAL3_CHECK 1505
#define IDC_GOTO_STANDING_CHECK 1506
#define IDC_GOTO_FLYING_CHECK 1507
#define IDC_GOTO_ROLLING_CHECK 1508
#define IDC_GOTO_WALKING_CHECK 1509
#define IDC_GOTO_JUMPING_CHECK 1510
#define IDC_ANIMSTATE_VIEW 1511
#define IDC_CURRENT_STATE_PULLDOWN 1512
#define IDC_ALERT_FROM_EDIT 1513
#define IDC_ALERT_TO_EDIT 1514
#define IDC_MISSILE1_TO_EDIT 1515
#define IDC_RECOIL1_FROM_EDIT 1516
#define IDC_DEFINE_ANIMSTATES 1517
#define IDC_ANIM_SOUND0_PULLDOWN 1517
#define IDC_FIRE_SOUND_PULLDOWN 1518
#define IDC_ANIM_SOUND1_PULLDOWN 1518
#define IDC_SOUND_FORWARD_RADIO 1519
#define IDC_FLYING_SOUND_PULLDOWN 1519
#define IDC_ANIM_SOUND2_PULLDOWN 1519
#define IDC_SOUND_BACKWARD_RADIO 1520
#define IDC_ANIM_SOUND3_PULLDOWN 1520
#define IDC_WEAPON_WALL_SOUND_PULLDOWN 1521
#define IDC_ANIM_SOUND4_PULLDOWN 1521
#define IDC_WEAPON_SPAWN_EDIT 1522
#define IDC_ANIM_SOUND5_PULLDOWN 1522
#define IDC_WEAPON_SPAWN_PULLDOWN 1523
#define IDC_ANIM_SOUND6_PULLDOWN 1523
#define IDC_RESET_ANIM_ZERO 1524
#define IDC_WEAPON_FIRE_DELAY_EDIT 1525
#define IDC_WB_FIRE1_SOUND_PULLDOWN 1525
#define IDC_ANIM_SOUND7_PULLDOWN 1525
#define IDC_WB_FIRE2_SOUND_PULLDOWN 1526
#define IDC_ANIM_SOUND8_PULLDOWN 1526
#define IDC_SOUNDPOSATTACH_RADIO 1527
#define IDC_WB_FIRE3_SOUND_PULLDOWN 1527
#define IDC_ANIM_SOUND9_PULLDOWN 1527
#define IDC_SOUNDWALLATTACH_RADIO2 1528
#define IDC_SOUNDOBJATTACH_RADIO 1528
#define IDC_WB_FIRE4_SOUND_PULLDOWN 1528
#define IDC_ANIM_SOUND10_PULLDOWN 1528
#define IDC_WB_FIRE5_SOUND_PULLDOWN 1529
#define IDC_ANIM_SOUND11_PULLDOWN 1529
#define IDC_LOOPING_CHECK 1530
#define IDC_ANIM_SOUND12_PULLDOWN 1530
#define IDC_SOUNDLOOPSTART_EDIT 1531
#define IDC_WB_FIRE6_SOUND_PULLDOWN 1531
#define IDC_ANIM_SOUND13_PULLDOWN 1531
#define IDC_SOUNDLOOPEND_EDIT 1532
#define IDC_WB_FIRE7_SOUND_PULLDOWN 1532
#define IDC_ANIM_SOUND14_PULLDOWN 1532
#define IDC_SOUNDEXCLUSIVE_CHECK 1533
#define IDC_ANIM_SOUND15_PULLDOWN 1533
#define IDC_SOUNDONCE_CHECK 1534
#define IDC_ANIM_SOUND16_PULLDOWN 1534
#define IDC_SOUNDCOPY_EDIT 1535
#define IDC_ANIM_SOUND17_PULLDOWN 1535
#define IDC_WEAPON_HOMING_CHECK 1536
#define IDC_ANIM_SOUND18_PULLDOWN 1536
#define IDC_SOUND_ONCE_PER_OBJ_CHECK 1536
#define IDC_WEAPON_BLOB_SIZE_EDIT 1537
#define IDC_WEAPON_IMPACT_SIZE_EDIT 1538
#define IDC_ANIM_SOUND19_PULLDOWN 1538
#define IDC_WEAPON_NUM_SHOTS_EDIT 1539
#define IDC_WEAPON_IMPACT_TIME_EDIT 1539
#define IDC_ANIM_SOUND20_PULLDOWN 1539
#define IDC_WEAPON_IMPACT_FORCE_EDIT 1539
#define IDC_MAKE_BLACK 1540
#define IDC_WEAPON_USE_PARENT_VELOCITY_CHECK 1540
#define IDC_ANIM_SOUND21_PULLDOWN 1540
#define IDC_SAVE_AS_TGA 1540
#define IDC_RUN16BIT_CHECK 1541
#define IDC_WEAPON_PERSISTANT_CHECK 1541
#define IDC_ANIM_SOUND22_PULLDOWN 1541
#define IDC_WEAPON_ALPHA_EDIT 1541
#define IDC_RESET_OBJECTS 1542
#define IDC_ANIM_SOUND23_PULLDOWN 1542
#define IDC_WEAPON_SCORCH_SIZE_EDIT 1542
#define IDC_LINK_TO_MINE 1543
#define IDC_WEAPON_IMPACT_DAMAGE_EDIT 1543
#define IDC_UNLINK_MINE 1544
#define IDC_WEAPON_IMPACT_TIME_EDIT2 1544
#define IDC_UNLINK_ALL 1545
#define IDC_WEAPON_IMPACT_GENERIC_DAMAGE_EDIT 1545
#define IDC_RESAVE 1546
#define IDC_ROT_LEFT 1547
#define IDC_ROT_RIGHT 1548
#define IDC_ADD_FILE 1561
#define IDC_LOCK_FILE 1562
#define IDC_CHECKIN_FILE 1563
#define IDC_PREV_FILE 1564
#define IDC_FILE_NAME 1565
#define IDC_FILE_DIRECTORY 1567
#define IDC_ADDITIONAL_STUFF_STATIC 1568
#define IDC_ROBOT_MOVES_CHECK 1569
#define IDC_ROBOT_GRAVITY_CHECK 1570
#define IDC_ROBOT_ONLY_PHYSICS_RADIO 1571
#define IDC_ROBOT_AI_PHYSICS_RADIO 1572
#define IDC_ROBOT_FIRE_WEAPON_1_CHECK 1574
#define IDC_SHOW_TERRAIN 1575
#define IDC_FLAT_SHADE_TERRAIN_CHECK 1576
#define IDC_SHOW_OBJ_TEXTURES 1577
#define IDC_TERRAIN_2D 1577
#define IDC_SHOW_TERRAIN_TEXTURES 1578
#define IDC_SHOW_LIGHT_TEXTURES 1579
#define IDC_SHOW_MINE_TEXTURES2 1580
#define IDC_RUN_OPENGL 1580
#define IDC_RED_LIGHTING 1581
#define IDC_FALLOFF_EDIT 1582
#define IDC_LIGHT_ITERATION_EDIT 1583
#define IDC_POWERUP_SCRIPT_EDIT 1584
#define IDC_HEMICUBE_RES_EDIT 1584
#define IDC_DELETE_MEGACELL 1585
#define IDC_LIGHT_SPACING_EDIT 1585
#define IDC_NEW_MEGACELL 1586
#define IDC_IGNORE_LIMIT_EDIT 1586
#define IDC_LOCK_MEGACELL 1587
#define IDC_CHECKIN_MEGACELL 1588
#define IDC_PREVIOUS_MEGACELL 1589
#define IDC_NEXT_MEGACELL 1590
#define IDC_MEGACELLS_OUT 1591
#define IDC_MEGA_WIDTH_EDIT 1592
#define IDC_MEGACELL_PULLDOWN 1593
#define IDC_MEGACELL_NAME_EDIT 1594
#define IDC_MEGACELL_VIEW 1595
#define IDC_ZBUFFER_CHECK 1596
#define IDC_MIPPING_CHECK 1596
#define IDC_BILINEAR_CHECK 1597
#define IDC_USE_MEGACELLS_CHECK 1597
#define IDC_IMPORT_MEGACELL 1598
#define IDC_REMAP_MEGACELL 1599
#define IDC_NEXT_MEGA_SET 1600
#define IDC_PREV_MEGA_SET 1601
#define IDC_MEGA_WIDTH_STATIC 1603
#define IDC_MEGA_HEIGHT_STATIC 1604
#define IDC_MEGACELL_NAME_STATIC 1605
#define IDC_RANDOMIZE_MEGACELL_CHECK 1606
#define IDC_MEGACELL_SET_VIEW 1607
#define IDC_FILL_WITH_MEGACELL 1609
#define IDC_COPY_MEGACELL 1610
#define IDC_PASTE_MEGACELL 1611
#define IDC_ROTATE_MEGACELL 1612
#define IDC_TERRAIN_UNDO 1613
#define IDC_TERRAIN_OCCLUSION 1613
#define IDC_TERR_SELECT_ALL 1614
#define IDC_USE_OPENGL 1616
#define IDC_USE_GLIDE 1617
#define IDC_UNIFY_MEGACELL 1618
#define IDC_SELECT_FROM_MEGACELL 1619
#define IDC_CLEAR_TMAP2 1620
#define IDC_ADD_NEW_SMALL 1621
#define IDC_ADD_NEW_TINY 1622
#define IDC_CONVERT_TO_NORMAL 1623
#define IDC_CONVERT_TO_TINY 1624
#define IDC_TEXTURE_WIDTH 1625
#define IDC_TEXTURE_HEIGHT 1626
#define IDC_IMPORT_TINY 1626
#define IDC_LOAD_ROOM 1627
#define IDC_ADD_NEW_HUGE 1627
#define IDC_SAVE_ROOM_LOCALLY 1628
#define IDC_SAVE_ROOM_NET 1629
#define IDC_VERTEX_COUNT 1630
#define IDC_FACE_COUNT 1631
#define IDC_ROOM_PULLDOWN 1632
#define IDC_FULLSCREEN_SW 1633
#define IDC_PALETTE_VERTEX_COUNT 1633
#define IDC_FULLSCREEN_HW 1634
#define IDC_PALETTE_FACE_COUNT 1634
#define IDC_ROOM_ENGINE 1635
#define IDC_PORTAL_COUNT 1635
#define IDC_HARDWARE_ACC 1636
#define IDC_PROPERTYTAB 1637
#define IDC_PTURNROLL 1638
#define IDC_PLEVELLING 1639
#define IDC_PBOUNCE 1640
#define IDC_PVELOCITY_X 1641
#define IDC_PVELOCITY_Y 1642
#define IDC_PVELOCITY_Z 1643
#define IDC_PTHRUST_X 1644
#define IDC_PTHRUST_Y 1645
#define IDC_PTHRUST_Z 1646
#define IDC_PROTVEL_X 1647
#define IDC_PROTVEL_Y 1648
#define IDC_PROTVEL_Z 1649
#define IDC_PROTTHRUST_X 1650
#define IDC_PROTTHRUST_Y 1651
#define IDC_PROTTHRUST_Z 1652
#define IDC_PTURNROLLANGLE 1653
#define IDC_PNUM_BOUNCES 1654
#define IDC_PMASS 1655
#define IDC_PDRAG 1656
#define IDC_PFULL_THRUST 1657
#define IDC_PROTDRAG 1658
#define IDC_PFULL_ROTTHRUST 1659
#define IDC_PMAX_TURNROLL_RATE 1660
#define IDC_PTURNROLL_RATIO 1661
#define IDC_PWIGGLE_AMPLITUDE 1662
#define IDC_PWIGGLES_PER_SECOND 1663
#define IDC_PUNLIMBOUNCE 1664
#define IDC_RESET_ALL_TEXTURES 1665
#define IDC_STATUSPROGRESS 1666
#define IDC_SCRIPTVIEW 1668
#define IDC_SCRIPTEXTERNAL 1669
#define IDC_SET_EXTERNAL_VIEWER 1670
#define IDC_USE_EXTERNAL 1671
#define IDC_TEXTURE_SKY 1672
#define IDC_USE_FOG 1673
#define IDC_SKY_RED_EDIT 1674
#define IDC_SKY_GREEN_EDIT 1675
#define IDC_HORIZON_GREEN_EDIT 1676
#define IDC_USE_HALO 1676
#define IDC_FOG_GREEN_EDIT 1677
#define IDC_SCRIPT_COMPILE 1677
#define IDC_USE_ATMOSPHERE 1677
#define IDC_OSIRIS_ERROR 1678
#define IDC_ROTATE_STARS 1678
#define IDC_OSIRIS_PROGRESS 1679
#define IDC_ROTATE_SKY 1679
#define IDC_OSIRIS_DONE 1680
#define IDC_NO_LOD_ENGINE 1681
#define IDC_FOG_DISTANCE_EDIT 1682
#define IDC_PIXEL_ERROR_EDIT 1683
#define IDC_FILES_OUT 1684
#define IDC_FILEDIR_PULLDOWN 1685
#define IDC_WEAPON_COLLIDE_WITH_SIBLING_CHECK 1686
#define IDC_WEAPON_FIXED_ROTATE_CHECK 1687
#define IDC_WEAPON_WIND_CHECK 1688
#define IDC_WEAPON_FIXED_VELOCITY_CHECK 1689
#define IDC_MARK_ROOM 1690
#define IDC_ROOMPAD_NEXT_EDGE 1691
#define IDC_ROOMPAD_PITCH_BACKWARD 1692
#define IDC_ROOMPAD_PITCH_FORWARD 1693
#define IDC_ROOMPAD_BANK_RIGHT 1694
#define IDC_ROOMPAD_BANK_LEFT 1695
#define IDC_ROOMPAD_ROTATE_RIGHT 1696
#define IDC_ROOMPAD_ROTATE_LEFT 1697
#define IDC_ROOMPAD_EXPAND_EDGE 1698
#define IDC_ROOMPAD_CONTRACT_EDGE 1699
#define IDC_ROOMPAD_EXPAND_ROOM 1700
#define IDC_ROOMPAD_CONTRACT_ROOM 1701
#define IDC_ROOMPAD_EXPAND_FACE 1702
#define IDC_ROOMPAD_CONTRACT_FACE 1703
#define IDC_DEBUG_CHECK 1704
#define IDC_ROOMPAD_MOVE_BACKWARD 1704
#define IDC_TERRPAD_SELECTRANGE 1705
#define IDC_ROOMPAD_MOVE_DOWN 1705
#define IDC_LOWER_BOUND_EDIT 1706
#define IDC_ROOMPAD_MOVE_FORWARD 1706
#define IDC_UPPER_BOUND_EDIT 1707
#define IDC_ROOMPAD_MOVE_UP 1707
#define IDC_ROOMPAD_MOVE_RIGHT 1708
#define IDC_PHYSICS_MASS_EDIT 1708
#define IDC_ROOMPAD_MOVE_LEFT 1709
#define IDC_PHYSICS_DRAG_EDIT 1709
#define IDC_PHYSICS_ROTDRAG_EDIT 1710
#define IDC_PHYSICS_MAXTHRUST_EDIT 1711
#define IDC_PHYSICS_ROTTHRUST_EDIT 1712
#define IDC_PHYSICS_MAXTURNROLLRATE_EDIT 1713
#define IDC_PHYSICS_TURNROLLRATIO_EDIT 1714
#define IDC_PHYSICS_WIGGLESIZE_EDIT 1715
#define IDC_PHYSICS_WIGGLEFREQ_EDIT 1716
#define IDC_PHYSICS_WIND_CHECK 1719
#define IDC_PHYSICS_MAGNETISM_CHECK 1720
#define IDC_ROBOT_EDIT_PHYSICS 1721
#define IDC_PHYSICS_GRAVITY 1722
#define IDC_ROBOT_USES_PHYSICS 1723
#define IDC_T_MAX_SPEED_EDIT 1724
#define IDC_AI_FIRE_WEAPON_1_CHECK 1725
#define IDC_AI_TARGET_BY_DIST_CHECK 1725
#define IDC_AI_FIRE_WEAPON_2_CHECK 1726
#define IDC_AI_MELEE_1_CHECK 1727
#define IDC_AI_MELEE_2_CHECK 1728
#define IDC_AI_STAY_IN_OUT_CHECK 1729
#define IDC_ROBOT_USES_AI 1730
#define IDC_ROBOT_EDIT_AI 1731
#define IDC_PHYSICS_FULL_PHYSICS 1732
#define IDC_PHYSICS_MAXTHRUST_TEXT 1733
#define IDC_PHYSICS_ROTTHRUST_TEXT 1734
#define IDC_PHYSICS_MAXTURNROLLRATE_TEXT 1735
#define IDC_PHYSICS_TURNROLLRATIO_TEXT 1736
#define IDC_PHYSICS_ROTDRAG_TEXT 1737
#define IDC_PHYSICS_DRAG_TEXT 1738
#define IDC_PHYSICS_WIGGLE_CHECK 1739
#define IDC_PHYSICS_WIGGLESIZE_TEXT 1740
#define IDC_PHYSICS_WIGGLEFREQ_TEXT 1741
#define IDC_PHYSICS_WIGGLES_PER_SEC_TEXT 1741
#define IDC_WEAPON_HIT_ROBOT_SOUND_COMBO 1742
#define IDC_WEAPON_BOUNCE_SOUND_COMBO 1742
#define IDC_HIT_OBJECT_EXPLOSION 1743
#define IDC_GENERIC_TYPE_NAME 1744
#define IDC_GENERIC_EDIT_AI 1745
#define IDC_GENERIC_EDIT_PHYSICS 1746
#define IDC_GENERIC_USES_AI 1747
#define IDC_GENERIC_USES_PHYSICS 1748
#define IDC_GENERIC_ADD_NEW 1749
#define IDC_GENERIC_DELETE 1750
#define IDC_GENERIC_LOCK 1751
#define IDC_GENERIC_CHECKIN 1752
#define IDC_GENERIC_PREV 1753
#define IDC_GENERIC_NEXT 1754
#define IDC_GENERIC_CHECKED_OUT 1755
#define IDC_GENERIC_VIEW 1756
#define IDC_GENERIC_OBJECTVIEW 1756
#define IDC_GENERIC_DEFINE_ANIMSTATES 1757
#define IDC_GENERIC_MODEL_NAME_EDIT 1759
#define IDC_GENERIC_ID_EDIT 1760
#define IDC_GENERIC_CHANGE_MODEL 1761
#define IDC_GENERIC_CHANGE_NAME 1762
#define IDC_GENERIC_COPY 1763
#define IDC_GENERIC_PASTE 1764
#define IDC_GENERIC_EXPLOSION 1765
#define IDC_GENERIC_NAME_PULLDOWN 1768
#define IDC_NAME_PULLDOWN 1768
#define IDC_PROMPT 1769
#define IDC_DEATH_POWERUP2_PULLDOWN 1769
#define IDC_PING_PONG 1770
#define IDC_DEATH_POWERUP1_PULLDOWN 1770
#define IDC_GENERIC_SIZE_EDIT 1771
#define IDC_SCRIPTID 1772
#define IDC_GENERIC_SCRIPT_ID_EDIT 1773
#define IDC_GENERIC_UNDO_LOCK 1774
#define IDC_PSHIP_EDIT_PHYSICS 1775
#define IDC_GENERIC_DESTROYABLE 1776
#define IDC_GENERIC_HITPOINT_EDIT 1777
#define IDC_SCR_LISTBOX 1778
#define IDC_GENERIC_AI_SCRIPTED_DEATH 1778
#define IDC_SCREVT_LISTBOX 1779
#define IDC_GENERIC_SCORE_EDIT 1779
#define IDC_ADDSCRIPT 1780
#define IDC_GENERIC_AMMO_EDIT 1780
#define IDC_ADDEVENT 1781
#define IDC_UNLOCK 1782
#define IDC_SELSCRIPT 1787
#define IDC_SCRIPVIEW 1789
#define IDC_BARREL_0_COMBO 1793
#define IDC_BARREL_1_COMBO 1794
#define IDC_BARREL_2_COMBO 1795
#define IDC_BARREL_3_COMBO 1796
#define IDC_BARREL_4_COMBO 1797
#define IDC_BARREL_5_COMBO 1798
#define IDC_TOTAL_GB_STATIC 1800
#define IDC_TOTAL_GP_STATIC 1801
#define IDC_BARREL_0_RADIO 1802
#define IDC_BARREL_1_RADIO 1803
#define IDC_BARREL_2_RADIO 1804
#define IDC_NUM_GB_TURRETS_STATIC 1805
#define IDC_GB_MASK_LATENCY_0_EDIT 1806
#define IDC_GB_NUM_MASKS_EDIT 1807
#define IDC_GENERIC_WEAPON_INFO_BUTTON 1808
#define IDC_ROOMPAD_NEXT_VERTEX 1809
#define IDC_ROOMPAD_COMBINE_FACES 1810
#define IDC_COORDSYS_SELECT 1811
#define IDC_OBJMOVEX 1812
#define IDC_OBJMOVEY 1813
#define IDC_OBJMOVEZ 1814
#define IDC_SHOW_ALPHAED_CHECK 1815
#define IDC_LIGHT_DISTANCE_EDIT 1816
#define IDC_BARREL_6_COMBO 1817
#define IDC_WEAPON_RED 1817
#define IDC_BARREL_7_COMBO 1818
#define IDC_WEAPON_GREEN 1818
#define IDC_WEAPON_BLUE 1819
#define IDC_TURRET_REACTION_TIME 1819
#define IDC_GENERIC_RED_LIGHT 1820
#define IDC_GENERIC_GREEN_LIGHT 1821
#define IDC_GENERIC_BLUE_LIGHT 1822
#define IDC_GENERIC_LIGHT_DISTANCE 1823
#define IDC_GENERIC_FLICKER_CHECK 1824
#define IDC_GENERIC_RED_LIGHT2 1824
#define IDC_SHOW_LIGHTMAPS 1825
#define IDC_GENERIC_PULSE_TIME 1825
#define IDC_TURRET_FOV_STATIC 1826
#define IDC_GENERIC_GREEN_LIGHT2 1826
#define IDC_TURRET_SPR_STATIC 1827
#define IDC_GENERIC_BLUE_LIGHT2 1827
#define IDC_TURRET_REACTION_TIME_STATIC 1828
#define IDC_TURRET_SOBJ_STATIC 1829
#define IDC_FLICKER_RADIO 1830
#define IDC_USE_TIMEBITS_RADIO 1831
#define IDC_GENERIC_LIGHT_BUTTON 1832
#define IDC_ALWAYS_ON_RADIO 1833
#define IDC_CURRET_TURRET_COMBO 1834
#define IDC_ROOMPAD_NEXT_PORTAL 1835
#define IDC_CURRENT_PORTAL 1836
#define IDC_RENDER_PORTAL_FACES 1837
#define IDC_TRIG_ADD_TO_CURFACE 1838
#define IDC_TRIG_ADD_TO_CURPORTAL 1839
#define IDC_SEC_PER_CYCLE_EDIT1 1840
#define IDC_SEC_PER_CYCLE_EDIT2 1841
#define IDC_VIEW_CONE_ANGLE_EDIT 1841
#define IDC_SEC_PER_CYCLE_EDIT3 1842
#define IDC_MAX_DISTANCE_EDIT 1842
#define IDC_SEC_PER_CYCLE_EDIT4 1843
#define IDC_VIEW_CONE_ANGLE_CHECK 1843
#define IDC_SEC_PER_CYCLE_EDIT5 1844
#define IDC_ROBOT_WEAPON_TEST_PULLDOWN 1844
#define IDC_SEC_PER_CYCLE_EDIT6 1845
#define IDC_SCRIPTSEL 1845
#define IDC_SEC_PER_CYCLE_EDIT7 1846
#define IDC_TEXTURE_CHANGE_NAME 1846
#define IDC_SEC_PER_CYCLE_EDIT8 1847
#define IDC_RENDER_STATIC 1847
#define IDC_SEC_PER_CYCLE_EDIT9 1848
#define IDC_RENDER_GOURAUD 1848
#define IDC_SCRIPTSEL_LISTBOX 1848
#define IDC_SEC_PER_CYCLE_EDIT10 1849
#define IDC_RENDER_LIGHTMAPS 1849
#define IDC_SCRIPTSEL_SCRIPT_WIZ 1849
#define IDC_SEC_PER_CYCLE_EDIT11 1850
#define IDC_SCRIPTSEL_MODULE 1850
#define IDC_SEC_PER_CYCLE_EDIT12 1851
#define IDC_TRIG_CURRENT_NUM 1851
#define IDC_SEC_PER_CYCLE_EDIT13 1852
#define IDC_TRIG_CURRENT_TYPE 1852
#define IDC_SEC_PER_CYCLE_EDIT14 1853
#define IDC_TRIG_CURRENT_ROOM 1853
#define IDC_SEC_PER_CYCLE_EDIT15 1854
#define IDC_TRIG_CURRENT_FACE 1854
#define IDC_SEC_PER_CYCLE_EDIT16 1855
#define IDC_TRIG_CURRENT_SCRIPT 1855
#define IDC_TRIG_CURRENT_TRIG_PORTAL 1855
#define IDC_SEC_PER_CYCLE_EDIT17 1856
#define IDC_TRIG_PREV_IN_MINE 1856
#define IDC_SEC_PER_CYCLE_EDIT18 1857
#define IDC_TRIG_NEXT_IN_MINE 1857
#define IDC_SEC_PER_CYCLE_EDIT19 1858
#define IDC_TRIG_GOTO 1858
#define IDC_SEC_PER_CYCLE_EDIT20 1859
#define IDC_TRIG_DELETE 1859
#define IDC_TIME_CHECK1 1860
#define IDC_SEC_PER_CYCLE_EDIT21 1860
#define IDC_PREV_DOOR 1860
#define IDC_SEC_PER_CYCLE_EDIT22 1861
#define IDC_NEXT_DOOR 1861
#define IDC_SEC_PER_CYCLE_EDIT23 1862
#define IDC_TRIG_ACTIVATORS 1862
#define IDC_SEC_PER_CYCLE_EDIT24 1863
#define IDC_TRIG_ACTIV_PLAYER 1863
#define IDC_TRIG_ONESHOT 1864
#define IDC_TRIG_FLOAT_WIDER 1865
#define IDC_TRIG_FLOAT_NARROWER 1866
#define IDC_TRIG_FLOAT_TALLER 1867
#define IDC_TRIG_FLOAT_SHORTER 1868
#define IDC_TRIG_FLOAT_BORDER 1869
#define IDC_TRIG_NEXT_PORTAL 1870
#define IDC_TRIG_CURRENT_PORTAL 1871
#define IDC_TRIG_NEXT_IN_ROOM 1872
#define IDC_TRIG_PREV_IN_ROOM 1873
#define IDC_SHOW_TMAP2_TEXTURES 1874
#define IDC_DEFAULT_RADIUS_BUTTON 1875
#define IDC_CURRENT_TEXTURE_NAME 1876
#define IDC_SKY_RADIO 1877
#define IDC_HORIZON_RADIO 1878
#define IDC_FOG_RADIO 1879
#define IDC_TIME_CHECK2 1880
#define IDC_SKY_SWATCH 1880
#define IDC_TIME_CHECK3 1881
#define IDC_HORIZON_SWATCH 1881
#define IDC_TIME_CHECK4 1882
#define IDC_FOG_SWATCH 1882
#define IDC_TIME_CHECK5 1883
#define IDC_SELECT_SLOPE_CHECK 1883
#define IDC_SATELLITE_RADIO 1883
#define IDC_TIME_CHECK6 1884
#define IDC_TYPESEL 1884
#define IDC_SATELLITE_SWATCH 1884
#define IDC_TIME_CHECK7 1885
#define IDC_BESTFIT_CHECK 1885
#define IDC_TIME_CHECK8 1886
#define IDC_DOORWAY_ID 1886
#define IDC_TIME_CHECK9 1887
#define IDC_PHYSICS_INIT_VELOCITY_EDIT 1887
#define IDC_TIME_CHECK10 1888
#define IDC_PHYSICS_INIT_ROT_VELOCITY_X_EDIT 1888
#define IDC_TIME_CHECK11 1889
#define IDC_PHYSICS_INIT_ROT_VELOCITY_Y_EDIT 1889
#define IDC_TIME_CHECK12 1890
#define IDC_PHYSICS_INIT_ROT_VELOCITY_Z_EDIT 1890
#define IDC_TIME_CHECK13 1891
#define IDC_PHYSICS_THRUSTS_CHECK 1891
#define IDC_TIME_CHECK14 1892
#define IDC_PHYSICS_GRAVITY_RADIO 1892
#define IDC_TIME_CHECK15 1893
#define IDC_PHYSICS_NO_GRAVITY_RADIO 1893
#define IDC_TIME_CHECK16 1894
#define IDC_PHYSICS_REVERSE_GRAVITY_RADIO 1894
#define IDC_PHYSICS_FIXED_VELOCITY_CHECK 1895
#define IDC_PHYSICS_FIXED_ROTATE_CHECK 1896
#define IDC_TIME_CHECK17 1897
#define IDC_PHYSICS_PERCENT_LOSS_EDIT 1897
#define IDC_TIME_CHECK18 1898
#define IDC_PHYSICS_BOUNCY_CHECK 1898
#define IDC_TIME_CHECK19 1899
#define IDC_PHYSICS_STICKY_CHECK 1899
#define IDC_TIME_CHECK20 1900
#define IDC_PHYSICS_MAX_BOUNCES_EDIT 1900
#define IDC_TIME_CHECK21 1901
#define IDC_TURN_ROLL_CHECK 1901
#define IDC_TIME_CHECK22 1902
#define IDC_MAX_BOUNCES_TEXT 1902
#define IDC_TIME_CHECK23 1903
#define IDC_PERCENT_LOSS_TEXT 1903
#define IDC_TIME_CHECK24 1904
#define IDC_EXTERNAL_ROOM 1904
#define IDC_PHYSICS_HIT_DIE_ANGLE 1904
#define IDC_TIME_CHECK25 1905
#define IDC_TOGGLE_VISIBILITY 1905
#define IDC_TIME_CHECK26 1906
#define IDC_SHOW_INVISIBLE 1906
#define IDC_TIME_CHECK27 1907
#define IDC_KEY1_CHECK 1907
#define IDC_TIME_CHECK28 1908
#define IDC_KEY2_CHECK 1908
#define IDC_MOVE_SAT_UP 1908
#define IDC_TIME_CHECK29 1909
#define IDC_KEY3_CHECK 1909
#define IDC_MOVE_SAT_DOWN 1909
#define IDC_TIME_CHECK30 1910
#define IDC_KEY4_CHECK 1910
#define IDC_MOVE_SAT_LEFT 1910
#define IDC_TIME_CHECK31 1911
#define IDC_MOVE_SAT_RIGHT 1911
#define IDC_KEY5_CHECK 1911
#define IDC_TIME_CHECK32 1912
#define IDC_SELECT_SCRIPT 1912
#define IDC_KEY6_CHECK 1912
#define IDC_CREATE_VOLUME_CONE 1913
#define IDC_KEY7_CHECK 1913
#define IDC_FILL_VOLUME_TEXTURE 1914
#define IDC_KEY8_CHECK 1914
#define IDC_CLEAR_VOLUMETRIC_ROOM 1915
#define IDC_EDGE_VOLUMETRIC 1916
#define IDC_FARTHEST_POINT 1917
#define IDC_NULL_DYING 1918
#define IDC_SMOKE_CHECK 1919
#define IDC_AI_USES_THRUST_CHECK 1920
#define IDC_PLANAR_SMOKE_CHECK 1920
#define IDC_AI_CLASS_COMBO 1921
#define IDC_AI_FOV_EDIT 1922
#define IDC_AI_FLOCK_COHESION_EDIT 1923
#define IDC_HEMICUBE_CHECK 1924
#define IDC_AI_FOV_EDIT2 1924
#define IDC_AI_DODGE_PER_EDIT 1924
#define IDC_NO_COLLIDE_CHECK 1925
#define IDC_ELEMENT_CHECK 1925
#define IDC_PULSE_TO_SECOND 1926
#define IDC_IGNORE_TERRAIN 1926
#define IDC_WEAPON_STICK_CHECK 1927
#define IDC_IGNORE_SATELLITES 1927
#define IDC_EDIT_PHYSICS 1928
#define IDC_USE_BSP_CHECK 1928
#define IDC_CHANGE_NAME 1929
#define IDC_WEAPON_LIGHT_INFO 1930
#define IDC_LAUNCH0 1931
#define IDC_LAUNCH1 1932
#define IDC_LAUNCH2 1933
#define IDC_LAUNCH3 1934
#define IDC_LAUNCH_MID 1935
#define IDC_WEAPON_VISUALS 1936
#define IDC_EDIT_WEAPONS 1937
#define IDC_EDIT_WB_BUTTON 1938
#define IDC_CURRENT_WEAPON_BATTERY_COMBO 1939
#define IDC_RENDER_EXTERNAL_ROOMS 1940
#define IDC_ELECTRICAL_CHECK 1941
#define IDC_FLICKER_SLIGHTLY_CHECK 1942
#define IDC_FLICKER_SLIGHTLY_EDIT 1943
#define IDC_NUM_POLYS 1944
#define IDC_ENERGY_USAGE_EDIT 1945
#define IDC_AMMO_USAGE_EDIT 1946
#define IDC_REPLACE_TEXTURE 1947
#define IDC_COUNT_TERRAIN_LIGHTS 1948
#define IDC_CURROOM_RADIOSITY 1949
#define IDC_DEFAULT_SIZE 1950
#define IDC_SIZE_MESSAGE 1951
#define IDC_DYNAMIC_TERRAIN 1952
#define IDC_ENABLE_SHADOWS_CHECK 1954
#define IDC_GENERIC_CONCUSSIVE_CHECK 1955
#define IDC_HIRES_RADIO 1956
#define IDC_MEDRES_RADIO 1957
#define IDC_LORES_RADIO 1958
#define IDC_NOLOD 1959
#define IDC_BLUR_LIGHTMAPS 1960
#define IDC_SOUND_MEMORY_STATIC 1962
#define IDC_SMOKE_PULLDOWN 1963
#define IDC_EXPLODE_PULLDOWN 1964
#define IDC_SOUND_NO_UPDATE 1964
#define IDC_SMOOTH_TERRAIN 1965
#define IDC_SCORCH_PULLDOWN 1965
#define IDC_TEXTURE_AMBIENT_SOUND_PULLDOWN 1966
#define IDC_WB_FIRE0_SOUND_PULLDOWN 1967
#define IDC_PARM1 1968
#define IDC_RELEASE_SOUND_PULLDOWN 1968
#define IDC_PARM2 1969
#define IDC_PARM3 1970
#define IDC_PARM4 1971
#define IDC_PARM5 1972
#define IDC_PARM6 1973
#define IDC_PARM7 1974
#define IDC_PARM8 1975
#define IDC_PARAMETERS 1976
#define IDC_HIGHLIGHT_BORDERS 1977
#define IDC_SPRAY_CHECK 1978
#define IDC_DOOR_CHANGE_NAME 1979
#define IDC_PARAMLIST 1980
#define IDC_PARAMLIST2 1981
#define IDC_OBJTREE 1981
#define IDC_PARAMLIST3 1982
#define IDC_AI_NOTIFY_SEEPLAYER_CHECK 1982
#define IDC_PARAMLIST4 1983
#define IDC_AI_RETARGET_CHECK 1983
#define IDC_PARAMLIST5 1984
#define IDC_USEFORMELEE1_CHECK 1984
#define IDC_PARAMLIST6 1985
#define IDC_USEFORMELEE2_CHECK 1985
#define IDC_PARAMLIST7 1986
#define IDC_INSTANT_CHECK 1986
#define IDC_PARAMLIST8 1987
#define IDC_PERSISTANT_CHECK 1987
#define IDC_INVISIBLE 1988
#define IDC_EXPLODE_RING 1991
#define IDC_SATURATE_CHECK 1992
#define IDC_PLANAR_CHECK 1993
#define IDC_ENABLE_CAMERA 1994
#define IDC_AI_FLUCTUATE_PROPERTIES 1995
#define IDC_NEXT_FACE 1996
#define IDC_FORCEFIELD_CHECK 1997
#define IDC_CURRENT_FACE 1998
#define IDC_TOUCHES_OUTSIDE 1999
#define IDC_PULSE_ROOM 2000
#define IDC_SECRET_CHECK 2000
#define IDC_ROOMPAD_REFUELING_CENTER 2001
#define IDC_SPAWNS_ON_IMPACT 2002
#define IDC_SPAWNS_ON_TIMEOUT 2003
#define IDC_CONTINUOUS_FIRING_SOUND 2003
#define IDC_FIRING_SOUND_PULLDOWN 2004
#define IDC_OVERRIDE 2005
#define IDC_GENERIC_INVEN_SELECTABLE 2006
#define IDC_SCRIPTSEL_ADD 2007
#define IDC_AI_HOSTILE_RADIO 2009
#define IDC_AI_NEUTRAL_RADIO 2010
#define IDC_TEXTURE_SWATCH 2011
#define IDC_LINENUM 2012
#define IDC_PHYSICS_TERMINAL_VELOCITY_STATIC 2013
#define IDC_PHYSICS_TERMINAL_ROT_VELOCITY_STATIC 2014
#define IDC_PHYSICS_PERSISTENT_CHECK 2015
#define IDC_GOALFACE_CHECK 2016
#define IDC_DEFAULT_PILOT 2017
#define IDC_WB_MODEL_ANIM_RADIO 2018
#define IDC_AI_ORDERED_WB_FIRING_CHECK 2019
#define IDC_DROP_TERRAIN 2020
#define IDC_WB_RANDOM_CHECK 2021
#define IDC_SAVE_AS_PCX 2022
#define IDC_NO_EXT_ROOMS_OBJS 2023
#define IDC_GUIDED_CHECK 2024
#define IDC_WEAPON_COPY_BUTTON 2025
#define IDC_WEAPON_PASTE_BUTTON 2026
#define IDC_EXPANDING_CHECK 2027
#define IDC_PHYSICS_IGNORE_CONCUSSIVE_FORCES 2028
#define IDC_MUZZLE_FLASH 2030
#define IDC_MICROWAVE 2031
#define IDC_NAPALM 2032
#define IDC_REINIT_DOORWAYS 2033
#define IDC_RESET_MULTIPLES 2034
#define IDC_DESTROY_BSP 2035
#define IDC_COMBINE_FACES 2036
#define IDC_RESAVE_BITMAPS 2037
#define IDC_VOLUME_LIGHTS 2037
#define IDC_GENERIC_INVEN_NONUSEABLE 2038
#define IDC_GOTO 2040
#define IDC_PHYSICS_MAX_HIT_ANGLE 2041
#define IDC_AI_ORIENT_VEL_CHECK 2043
#define IDC_OBJPAD_RESET_CUROBJ_HEIGHT 2044
#define IDC_OBJPAD_RESET_ALL_OBJ_HEIGHTS 2045
#define IDC_IMPORT_BUMP 2045
#define IDC_GENERATE_OMNI 2046
#define IDC_SLEWSLIDER 2047
#define IDC_AI_XZ_TARGET_DIST 2048
#define IDC_SCRTYPE 2049
#define IDC_CORONA_CHECK 2050
#define IDC_SPEW_POWERUP_PULLDOWN 2052
#define IDC_PHYSICS_COPY 2053
#define IDC_PHYSICS_PASTE 2054
#define IDC_IMPORT_SKY 2055
#define IDC_FOG_CHECK 2056
#define IDC_MEGACELL_SKYDOME 2057
#define IDC_IMPORT_SKY_BAND 2058
#define IDC_MEGACELL_SKYBAND 2059
#define IDC_INVERSE_CHECK 2060
#define IDC_REVERSE_SMOKE_CHECK 2061
#define IDC_GRAVITY_FIELD_CHECK 2062
#define IDC_COUNTERMEASURE_CHECK 2063
#define IDC_PROCEDURAL_UPDATE 2064
#define IDC_PROCEDURAL_BUTTON 2065
#define IDC_PROCEDURAL_VIEW 2066
#define IDC_CLEAR_PROCEDURALS 2067
#define IDC_PROCEDURAL_PULLDOWN 2068
#define IDC_IMPORT_PALETTE 2072
#define IDC_PALETTE_VIEW 2074
#define IDC_DEFAULT_PALETTE 2075
#define IDC_SPECIAL_1 2076
#define IDC_SPECIAL_2 2077
#define IDC_SPECIAL_3 2078
#define IDC_SPECIAL_4 2079
#define IDC_SPECIAL_5 2080
#define IDC_SPECIAL_6 2081
#define IDC_BOA_VIS_BUTTON 2082
#define IDC_ROOM_CORONAS 2083
#define IDC_MINE_CORONAS 2084
#define IDC_FREEZE_CHECK 2084
#define IDC_EMD_CHECK 2085
#define IDC_HOMED_SPLIT_CHECK 2086
#define IDC_SILENT_HOMING_CHECK 2087
#define IDC_REVERSE_CORONA 2088
#define IDC_DEFAULTALLOW 2089
#define IDC_TABLEEDIT_BTN_PREVIOUS 2090
#define IDC_TABLEEDIT_BTN_NEXT 2091
#define IDC_WATER_PROCEDURAL_VIEW 2092
#define IDC_PROC_THICKNESS_EDIT 2093
#define IDC_PROC_LIGHT_EDIT 2094
#define IDC_PROC_HEIGHT_EDIT 2095
#define IDC_INVEN_NOREMOVE 2096
#define IDC_PROC_EVAL_TIME_EDIT 2096
#define IDC_ENABLE_QUAD 2097
#define IDC_PROC_OSC_TIME_EDIT 2097
#define IDC_PROC_OSC_VALUE_EDIT 2098
#define IDC_ROOM_AMBIENT 2100
#define IDC_AI_NV_SLIDER 2101
#define IDC_ASP_CHECK_IN 2101
#define IDC_AI_FV_SLIDER 2102
#define IDC_ASP_LIST 2102
#define IDC_ASP_NEW 2103
#define IDC_ASP_RENAME 2104
#define IDC_AI_FIGHT_TEAM_SLIDER 2105
#define IDC_ASP_ELEMENT_LIST 2105
#define IDC_AI_ROAMING_SLIDER 2106
#define IDC_ASP_NEW_ELEMENT 2106
#define IDC_AI_TLA_SLIDER 2107
#define IDC_ASP_EDIT_ELEMENT 2107
#define IDC_AI_HEARING_SLIDER 2108
#define IDC_ASE_SOUND_LIST 2108
#define IDC_AI_CURIOUSITY_SLIDER 2109
#define IDC_ASP_DELETE_ELEMENT 2109
#define IDC_AI_AGRESSION_SLIDER 2110
#define IDC_ASP_UNDO_LOCK 2110
#define IDC_AI_FIRE_SPREAD_SLIDER 2111
#define IDC_FACE_MAP 2111
#define IDC_AI_TLV_SLIDER 2112
#define IDC_PREV_START_POSITON 2112
#define IDC_AI_FRUSTRATION_SLIDER 2113
#define IDC_NEXT_START_POS 2113
#define IDC_AI_FIGHT_SAME_SLIDER 2114
#define IDC_JUMP_TO_START_POS 2114
#define IDC_AI_LIFE_PRESERVATION_SLIDER 2115
#define IDC_RED_CHECK 2115
#define IDC_START_POS_TEXT 2116
#define IDC_AI_CURIOUSITY_SLIDER2 2116
#define IDC_DIRECTIONAL 2117
#define IDC_AI_CURIOUSITY_SLIDER4 2117
#define IDC_MIRROR_FACE_TEXT 2118
#define IDC_AI_CURIOUSITY_SLIDER3 2118
#define IDC_MIRROR_BUTTON 2119
#define IDC_NO_MIRROR_BUTTON 2120
#define IDC_ROOMPAD_FLIP_FACE 2121
#define IDC_BRIEF_TITLE 2122
#define IDC_BRIEF_COLOR_R 2123
#define IDC_BRIEF_COLOR_G 2124
#define IDC_BRIEF_COLOR_B 2125
#define IDC_BRIEF_STATIC 2126
#define IDC_BRIEF_GLITCH 2127
#define IDC_BRIEF_FONT 2128
#define IDC_BRIEF_SCREEN_LIST 2129
#define IDC_BRIEF_SCREEN_DEL 2130
#define IDC_BRIEF_EFFECT_LIST 2131
#define IDC_BRIEF_EFFECT_DEL 2132
#define IDC_BRIEF_EFFECT_EDIT 2133
#define IDC_BRIEF_EFFECT_TEXT 2134
#define IDC_BRIEF_EFFECT_BITMAP 2135
#define IDC_BRIEF_EFFECT_POLYMODEL 2136
#define IDC_BRIEF_EFFECT_SOUND 2137
#define IDC_BRIEF_EFFECT_VOICE 2138
#define IDC_BRIEF_SAVE 2139
#define IDC_BRIEF_PICTURE 2140
#define IDC_BRIEF_ADDS_LAYOUT_LIST 2141
#define IDC_BRIEF_B_SPEED 2142
#define IDC_BRIEF_B_STARTTIME 2143
#define IDC_BRIEF_B_X 2144
#define IDC_BRIEF_B_Y 2145
#define IDC_BRIEF_B_FILENAME 2146
#define IDC_BRIEF_B_CHOOSE 2147
#define IDC_BRIEF_B_STATIC 2148
#define IDC_BRIEF_B_BLURIN 2149
#define IDC_BRIEF_B_BLUROUT 2150
#define IDC_BRIEF_B_SCANIN 2151
#define IDC_BRIEF_B_SCANOUT 2152
#define IDC_BRIEF_B_INVIN 2153
#define IDC_BRIEF_B_INVOUT 2154
#define IDC_BRIEF_B_STRETCHIN 2155
#define IDC_BRIEF_B_STRETCHOUT 2156
#define IDC_BRIEF_BT_FLASHER 2157
#define IDC_BRIEF_BT_FLASHSTART 2158
#define IDC_BRIEF_BT_FLASH_FILENAME 2159
#define IDC_BRIEF_BT_FLASH_CHOOSE 2160
#define IDC_BRIEF_BT_GLOW 2161
#define IDC_BRIEF_BT_ID 2162
#define IDC_BRIEF_BT_PID 2163
#define IDC_BRIEF_BT_SID 2164
#define IDC_BRIEF_BT_SCROLLUP 2165
#define IDC_BRIEF_BT_SCROLLDOWN 2166
#define IDC_BRIEF_BT_NEXTSCREEN 2167
#define IDC_BRIEF_BT_PREVSCREEN 2168
#define IDC_BRIEF_BT_QUIT 2169
#define IDC_BRIEF_BT_MOUSEUP 2170
#define IDC_BRIEF_BT_MOUSEDOWN 2171
#define IDC_BRIEF_BT_MOUSEHOLD 2172
#define IDC_BRIEF_BT_FILENAME 2173
#define IDC_BRIEF_M_X 2173
#define IDC_BRIEF_BT_CHOOSE 2174
#define IDC_BRIEF_M_Y 2174
#define IDC_BRIEF_M_FILENAME 2175
#define IDC_BRIEF_BT_FLASH_FILENAME_FOCUS 2175
#define IDC_BRIEF_M_CHOOSE 2176
#define IDC_BRIEF_BT_FLASH_CHOOSE_FOCUS 2176
#define IDC_BRIEF_M_LOOPING 2177
#define IDC_BRIEF_BT_FILENAME_FOCUS 2177
#define IDC_BRIEF_M_FPS 2178
#define IDC_BRIEF_BT_CHOOSE_FOCUS 2178
#define IDC_BRIEF_M_STARTTIME 2179
#define IDC_BRIEF_S_STARTTIME 2180
#define IDC_BRIEF_S_FILENAME 2181
#define IDC_BRIEF_S_CHOOSE 2182
#define IDC_BRIEF_S_PLAYONCE 2183
#define IDC_BRIEF_T_TEXT 2184
#define IDC_BRIEF_T_ID 2185
#define IDC_BRIEF_T_STARTTIME 2186
#define IDC_BRIEF_T_UL_X 2187
#define IDC_BRIEF_T_UL_Y 2188
#define IDC_BRIEF_T_LR_Y 2189
#define IDC_BRIEF_T_PREDEF 2190
#define IDC_BRIEF_T_STATIC 2191
#define IDC_BRIEF_T_TYPE 2192
#define IDC_BRIEF_T_FADEIN 2193
#define IDC_BRIEF_T_FADEOUT 2194
#define IDC_BRIEF_T_SL2R 2195
#define IDC_BRIEF_T_SR2L 2196
#define IDC_BRIEF_T_ST2B 2197
#define IDC_BRIEF_T_SB2T 2198
#define IDC_MAT_PASTE_OBJREF_BUTTON 2199
#define IDC_BRIEF_T_FONT 2199
#define IDC_MAT_NEXT_BUTTON 2200
#define IDC_MAT_PREV_BUTTON 2201
#define IDC_MAT_NEW_BUTTON 2202
#define IDC_MAT_COPY_BUTTON 2203
#define IDC_MAT_PASTE_BUTTON 2204
#define IDC_MAT_CUR_STATIC 2205
#define IDC_MAT_NUM_STATIC 2206
#define IDC_MAT_NAME_EDIT 2207
#define IDC_MAT_ROOM_RADIO 2208
#define IDC_MAT_OBJECT_RADIO 2209
#define IDC_MAT_DELETE_BUTTON 2210
#define IDC_MAT_PROD_7_COMBO 2211
#define IDC_MAT_PROD_3_QUATITY_EDIT 2212
#define IDC_MAT_PROD_4_QUATITY_EDIT 2213
#define IDC_MAT_ENABLED_CHECK 2214
#define IDC_MAT_ORDERED_RADIO 2215
#define IDC_MAT_SC_RADIO 2216
#define IDC_MAT_ENABLED_SOUND_COMBO 2217
#define IDC_MAT_DISABLED_SOUND_COMBO 2218
#define IDC_JOYENABLE 2219
#define IDC_MAT_NHP_CHECK 2219
#define IDC_BRIEF_BT_DESC 2220
#define IDC_BRIEF_M_DESC 2221
#define IDC_BRIEF_S_DESC 2222
#define IDC_BRIEF_T_DESC 2223
#define IDC_BRIEF_ADDS_DESC 2224
#define IDC_NO_ROTATE_CHECK 2225
#define IDC_STRINGLIST 2226
#define IDC_LOADSCRIPT 2227
#define IDC_BRIEF_B_PREDEF 2228
#define IDC_BRIEF_ADDS_PICTURE 2229
#define IDC_EFFECTNAME_LIST 2230
#define IDC_ADD_EFFECT 2231
#define IDC_DEL_EFFECT 2232
#define IDC_FORCE_TYPE 2233
#define IDC_GEN_DUR_INFINITE 2234
#define IDC_USE_ENVELOPE 2235
#define IDC_PER_MAGNITUDE 2236
#define IDC_PER_OFFSET 2237
#define IDC_PER_PHASE 2238
#define IDC_PER_PERIOD 2239
#define IDC_CON_MAGNITUDE 2240
#define IDC_PLAY_EFFECT 2241
#define IDC_STOP_EFFECT 2242
#define IDC_CUSTOM1 2244
#define IDC_BRIEF_BT_X 2245
#define IDC_BRIEF_BT_Y 2246
#define IDC_CLEAR 2247
#define IDC_LEVEL_PREV_GOAL_BUTTON 2248
#define IDC_LEVEL_NEW_GOAL_BUTTON 2249
#define IDC_LEVEL_NEXT_GOAL_BUTTON 2250
#define IDC_LEVEL_DELETE_GOAL_BUTTON 2251
#define IDC_LEVEL_PASTE_GOAL_BUTTON 2252
#define IDC_LEVEL_GOAL_NEXT_ITEM_BUTTON 2253
#define IDC_LEVEL_GOAL_DELETE_ITEM_BUTTON 2254
#define IDC_LEVEL_GOAL_CELL_ITEM_RADIO 2255
#define IDC_LEVEL_GOAL_COMPLETED_CHECK 2256
#define IDC_LEVEL_GOAL_GDKL_CHECK 2257
#define IDC_LEVEL_GOAL_CUR_ITEM_STATIC 2258
#define IDC_LEVEL_GOAL_NUM_ITEMS_STATIC 2259
#define IDC_LEVEL_GOAL_NUM_GOALS_STATIC 2260
#define IDC_LEVEL_GOAL_CUR_GOAL_STATIC 2261
#define IDC_FORCE_VISIBLE 2262
#define IDC_LEVEL_GOAL_END_LEVEL_CHECK 2262
#define IDC_ROOMPAD_ONE_ROOM_ONLY 2263
#define IDC_LEVEL_GOAL_CELL_ITEM_RADIO2 2263
#define IDC_LEVEL_GOAL_MINE_RADIO 2263
#define IDC_ROOMPAD_NO_DRAW_TERRAIN 2264
#define IDC_TABLEFILTER_LEVEL_LIST 2265
#define IDC_TABLEFILTER_BTN_ADDLEVEL 2266
#define IDC_TABLEFILTER_BTN_REMOVELEVEL 2267
#define IDC_TABLEFILTER_DATA_LIST 2268
#define IDC_TABLEFILTER_BTN_ADDPAGE 2269
#define IDC_TABLEFILTER_BTN_REMOVEPAGE 2270
#define IDC_TABLEFILTER_BTN_CREATENEWTABLEFILE 2271
#define IDC_TABLEFILTER_STATUSTEXT 2272
#define IDC_TABLEFILTER_NUMPAGESTEXT 2273
#define IDC_TRIANGULATE 2274
#define IDC_TABLEFILEFILTER_ADDTYPE_COMBO 2275
#define IDC_OBJECT_SWAP_BUTTON 2276
#define IDC_SWAP_SOURCE_COMBO 2277
#define IDC_REGROUND_COMBO 2278
#define IDC_RICHFRAME 2281
#define IDC_TABSTOP 2282
#define IDC_SHOW_TENTHS 2283
#define IDC_CUSTOM_SIZE_CHECK 2284
#define IDC_TEXTURE_RAM_TEXT 2285
#define IDC_L_X_CHECK 2286
#define IDC_L_Y_CHECK 2287
#define IDC_NO_BIG_SPHERE_CHECK 2288
#define IDC_REGROUND_BUTTON 2289
#define IDC_ONOFF_CHECK 2290
#define IDC_DIRECTIONS_TEXT 2291
#define IDC_MULTICHECKIN_LISTBOX 2292
#define IDC_MULTICHECKTEX 2293
#define IDC_ELECTIC_TRACER_CHECK 2295
#define IDC_USER_TIMEOUT_CHECK 2296
#define IDC_BFHI_SLIDER 2297
#define IDC_CURRENT_USED 2298
#define IDC_LIST_AVAILABLE 2299
#define IDC_AVAILABLE_GRP 2300
#define IDC_LIST_CHECKEDOUT 2301
#define IDC_CHECKEDOUT_GRP 2302
#define IDC_CHECKOUT 2303
#define IDC_UNDOCHECKOUT 2304
#define IDC_SELECTED_SCRIPT 2305
#define IDC_ADDNEW 2306
#define IDC_NEW_EVENT_BUTTON 2307
#define IDC_PASTE_BUTTON 2308
#define IDC_DELETE_EVENT_BUTTON 2309
#define IDC_IMPORT_BUTTON 2310
#define IDC_NEW_MESSAGE_BUTTON 2311
#define IDC_DELETE_MESSAGE_BUTTON 2312
#define IDC_CREATESCRIPT 2313
#define IDC_EXPAND_ALL_BUTTON 2313
#define IDC_STATUS 2314
#define IDC_COLLAPSE_ALL_BUTTON 2314
#define IDC_CONFIGCOMPILER 2315
#define IDC_C7 2316
#define IDC_BROWSE 2318
#define IDC_WARN_NONE 2319
#define IDC_SCRIPTGAME 2320
#define IDC_SCRIPTLEVEL 2321
#define IDC_GENERIC_PROMPT_STATIC 2322
#define IDC_CHANGE_MESSAGE_NAME_BUTTON 2323
#define IDC_AMB_OUTSIDE1 2324
#define IDC_AMB_OUTSIDE2 2325
#define IDC_AMB_OUTSIDE3 2326
#define IDC_DATA1_EDIT 2326
#define IDC_AMB_OUTSIDE4 2327
#define IDC_DATA3_EDIT 2327
#define IDC_STEP1 2327
#define IDC_AMB_OUTSIDE5 2328
#define IDC_DATA2_EDIT 2328
#define IDC_STEP2 2328
#define IDC_AMB_OUTSIDE6 2329
#define IDC_STEP3 2329
#define IDC_STEP4 2330
#define IDC_BUILD 2331
#define IDC_AUTOCHECKIN 2332
#define IDC_LIST 2333
#define IDC_MASSCOMPILE 2334
#define IDC_SAVE_BUTTON 2335
#define IDC_LIST_NONCHECKED_OUT 2336
#define IDC_FILELIST 2337
#define IDC_CHECKEDOUT_LIST 2338
#define IDC_DIRECTORY_FILTER 2339
#define IDC_ROOM_NAME 2340
#define IDC_EDIT_NAME 2341
#define IDC_WP_HEIGHT_SLIDER 2342
#define IDC_WP_FREQUENCY_SLIDER 2343
#define IDC_WP_SIZE_SLIDER 2344
#define IDC_HEIGHT_TEXT 2345
#define IDC_FREQ_TEXT 2346
#define IDC_HEAT_TEXT 2346
#define IDC_SIZE_TEXT 2347
#define IDC_FP_HEAT_SLIDER 2347
#define IDC_WP_THICKNESS_SLIDER 2348
#define IDC_SIZE_SLIDER 2348
#define IDC_COMPILEMODULE 2348
#define IDC_THICKNESS_TEXT 2349
#define IDC_SIZE_TEXT2 2349
#define IDC_BOTH 2349
#define IDC_WP_LIGHT_SLIDER 2350
#define IDC_FREQ_SLIDER 2350
#define IDC_LIGHTING_COMPLETE 2350
#define IDC_LIGHT_TEXT 2351
#define IDC_FREQUENCY_TEXT 2351
#define IDC_STOP_LIGHTING 2351
#define IDC_SPEED_SLIDER 2352
#define IDC_MISSIONFLAGS 2352
#define IDC_SPEED_TEXT 2353
#define IDC_SELECTALL 2353
#define IDC_OODSCRIPTS 2354
#define IDC_HIGHLIGHT_BUTTON 2355
#define IDC_OOSSCRIPTS 2355
#define IDC_TRIG_CURRENT_NAME 2356
#define IDC_TRIG_EDIT_SCRIPT 2357
#define IDC_UTYPES_BUTTON 2357
#define IDC_TRIG_EDIT_NAME 2358
#define IDC_DEATH_DELAY_LOSES_ANTIGRAV 2359
#define IDC_DEATH_COMMON_DESCENT 2360
#define IDC_DEATH_COMMON_QUICK_EXPLOSION 2361
#define IDC_DEATH_COMMON_SHOOT_UP 2362
#define IDC_DEATH_COMMON_R2D2 2363
#define IDC_DEATH_COMMON_ANIMAL 2364
#define IDC_DEATH_COPY 2365
#define IDC_DEATH_PASTE 2366
#define IDC_DEATH_DELAY_GROUP 2367
#define IDC_DEATH_DELAY_FADE_AWAY 2368
#define IDC_DEATH_EXPLOSION_OPTIONS_GROUP 2369
#define IDC_DEATH_FALLING_OPTIONS_GROUP 2370
#define IDC_DEATH_FADES_AWAY 2370
#define IDC_DEATH_CONTACT_GROUP 2371
#define IDC_DEATH_DEBRIS_CONTACT_GROUP 2372
#define IDC_DEATH_STATIC 2373
#define IDC_DEATH_DELAY_MIN_LABEL 2374
#define IDC_DEATH_DELAY_MAX_LABEL 2375
#define IDC_PLAY_SOUND_BUTTON 2376
#define IDC_DEATH_DELAY_SOUND 2376
#define IDC_STOP_SOUNDS_BUTTON 2377
#define IDC_SOUND_LIST 2378
#define IDC_STROBE_CHECK 2379
#define IDC_FLICKER_CHECK 2380
#define IDC_FLAG_LIST 2380
#define IDC_FLAG_PROMPT_STATIC 2381
#define IDC_TEXTURE_LIST 2382
#define IDC_TEXTURE_GRID_CHECK 2383
#define IDC_TILE_MORE 2384
#define IDC_SELECT_CUR_TEXTURE_CHECK 2384
#define IDC_TILE_LESS 2385
#define IDC_FORCE_TO_FVEC_CHECK 2386
#define IDC_UTYPE_COMBO 2387
#define IDC_FORCE_TO_TARGET_CHECK 2387
#define IDC_VALUES_LIST 2388
#define IDC_CHANGE_BUTTON 2389
#define IDC_ADD_BUTTON 2390
#define IDC_DELETE_BUTTON 2391
#define IDC_OBJ_ROT90 2392
#define IDC_DOORWAY_CURRENT_BOX 2393
#define IDC_DOORWAY_POS_TEXT 2394
#define IDC_DOORWAY_KEYS_TEXT 2395
#define IDC_WBAIMFORWARD_CHECK 2396
#define IDC_ALLOBJ_RADIO 2397
#define IDC_ALLTRIG_RADIO 2398
#define IDC_LEVEL_RADIO 2399
#define IDC_ROOMPAD_DAMAGETYPE 2400
#define IDC_DOORWAY_HITPOINT_TEXT 2401
#define IDC_DOOR_HITPOINTS_TEXT 2402
#define IDC_SCRIPT_LIST 2403
#define IDC_DOORWAY_KEY_ONLY_ONE 2404
#define IDC_TIMEOUT_WALL_CHECK 2405
#define IDC_MANAGE 2406
#define IDC_ADD 2407
#define IDC_AI_AIM_WITH_UVEC 2408
#define IDC_LIST_FOLDERS 2409
#define IDC_LIST_FILES 2410
#define IDC_DIRS 2411
#define IDC_CURRPATH 2412
#define IDC_AUTOCHECKSCRIPTS 2413
#define IDC_BRIEF_B_NORENDER 2414
#define IDC_STRM_AUDIO_LIST 2415
#define IDC_PLAY_STRM_AUDIO_BUTTON 2416
#define IDC_TRIGGER_RADIO 2417
#define IDC_LG_ACTIVATE_RADIO 2418
#define IDC_LG_LC_RADIO 2419
#define IDC_TERRAIN_SOUND_NEXT 2420
#define IDC_TERRAIN_SOUND_PREV 2421
#define IDC_TERRAIN_SOUND_HIGH_ALT 2422
#define IDC_TERRAIN_SOUND_BAND_TEXT 2423
#define IDC_TERR_SOUND 2424
#define IDC_SOUND_COMBO 2425
#define IDC_SOUND_CHANGE_NAME 2426
#define IDC_NO_SPECULAR_CHECK 2427
#define IDC_DEATH_DELAY_FROM_ANIM 2428
#define IDC_DEATH_DEBRIS_OPTIONS_GROUP 2429
#define IDC_GENERIC_DEATHS 2430
#define IDC_GENERIC_DEATH_EDIT1 2431
#define IDC_GENERIC_DEATH_EDIT2 2432
#define IDC_DIRECTORY 2432
#define IDC_GENERIC_DEATH_EDIT3 2433
#define IDC_STATS 2433
#define IDC_GENERIC_DEATH_EDIT4 2434
#define IDC_AIM_FOV_CHECK 2434
#define IDC_OBJECT_PUSHTHROUGHWALLS 2435
#define IDC_SELECT 2436
#define IDC_RENDER_SHELL 2437
#define IDC_RENDER_NON_SHELL 2438
#define IDC_AMBIENT_SOUND_SELECT 2439
#define IDC_IGC_ENABLED 2440
#define IDC_NOCHECKOUT 2441
#define IDC_FIND_TEXTURE 2442
#define IDC_AIN_CREATE_NODE_AT_VIEWER 2443
#define IDC_AIN_RESET_ROOM_NODES 2444
#define IDC_AIN_MAKE_EDGE 2445
#define IDC_AIN_DOWN 2446
#define IDC_AIN_AUTO_EDGE_NODE 2447
#define IDC_AIN_SEL_ROOM_AND_NEXT_ROOMS 2448
#define IDC_AIN_VERIFY_ROOM 2449
#define IDC_AIN_VERIFY_LEVEL 2450
#define IDC_AIN_CREATE_NODES 2451
#define IDC_AIN_VIEW_ROOM 2452
#define IDC_AIN_VIEW_NONE 2453
#define IDC_AIN_CURRENT_NODE 2454
#define IDC_EVENT_RADIO 2455
#define IDC_AER_BUTTON 2455
#define IDC_EVENT_COMBO 2456
#define IDC_YPOS_EDIT 2457
#define IDC_XMOVE_CHECK 2458
#define IDC_YMOVE_CHECK 2459
#define IDC_POS_COMMIT_BUTTON 2460
#define IDC_HEADING_EDIT 2461
#define IDC_ALIGN_XPOS_BUTTON 2462
#define IDC_ALIGN_XNEG_BUTTON 2463
#define IDC_ALIGN_ZNEG_BUTTON 2464
#define IDC_ORIENT_COMMIT_BUTTON 2465
#define IDC_GENERIC_AMMO_TEXT 2466
#define IDC_LEVEL_CEILING_EVERYWHERE 2467
#define IDC_OBJ_CEILING_CHECK 2468
#define IDC_LEVEL_PIW 2468
#define IDC_OBJECT_FLY_THROUGH_RENDERED_PORTALS 2469
#define IDC_IENAV_BUTTON 2470
#define IDC_PORTAL_BLOCKED_CHECK 2471
#define IDC_PORTAL_BLOCKED_CAN_GO_AWAY_CHECK 2472
#define IDC_BAD_CENTERPOINTS 2473
#define IDC_DSMPBD_CHECK 2474
#define IDC_CLEAR_LIGHTMAPS 2475
#define IDC_DOORWAY_GB_IGNORE_LOCKED 2476
#define IDC_COPY_MULTIPLIER 2476
#define IDC_ONTVGP_BUTTON 2477
#define IDC_MAT_ROOM_OBJECT_COMBO 2478
#define IDC_GENERIC_AMBIENT 2479
#define IDC_COPY_PROCEDURAL 2480
#define IDC_PROC_COPY_LIST 2481
#define IDC_ROOM_SKIP_LIGHTING 2482
#define HID_TEXTURETAB 5000
#define HID_TERRAINTAB 5001
#define HID_OBJECTTAB 5002
#define HID_SEGMENTTAB 5003
#define HID_DOORWAYTAB 5004
#define HID_TRIGGERTAB 5005
#define HID_LIGHTINGTAB 5006
#define HID_CURVETAB 5007
#define HID_PATHSTAB 5008
#define HID_TEXTURESDLG 5009
#define HID_ROBOTSDLG 5010
#define HID_AIDLG 5011
#define HID_POWERUPSDLG 5012
#define HID_WEAPONSDLG 5013
#define HID_PLAYERSHIPSDLG 5014
#define HID_DOORSDLG 5015
#define HID_SOUNDSDLG 5016
#define HID_LIGHTSDLG 5017
#define HID_FONTEDITORDLG 5018
#define HID_HOGMAKERDLG 5019
#define HID_BMPANIDLG 5020
#define HID_GENERAL 5021
#define HID_DEFAULT 5022
#define HID_MEGACELLTAB 5023
#define HID_ROOMTAB 5024
#define HID_MEGACELLDLG 5025
#define ID_CANCEL_EDIT_SRVR 32769
#define IDC_WIREFRAME_WND 32771
#define IDC_TEXTURE_WND 32772
#define ID_FILE_PLAYIN640X480 32778
#define ID_FILE_AUTOSAVE 32779
#define ID_FILE_RESTOREGAMESTATE 32780
#define ID_TOOLS_WORLD_TEXTURES 32785
#define ID_TOOLS_WORLD_WEAPONS 32792
#define ID_TOOLS_WORLD_OBJECTS_DOOR 32793
#define ID_TOOLS_WORLD_OBJECTS_ROBOTS 32794
#define ID_TOOLS_WORLD_OBJECTS_POWERUPS 32795
#define ID_TOOLS_WORLD_OBJECTS_LIGHTS 32796
#define ID_TOOLS_WORLD_OBJECTS_PLAYER 32797
#define ID_SUBEDITORS_FONT 32799
#define ID_SUBEDITORS_HOGMAKER 32800
#define ID_FILE_LOADD2LVL 32801
#define ID_BUTTON_OUTLINE 32803
#define ID_VIEW_KEYPAD_TOGGLE 32805
#define ID_WINDOW_TILE 32806
#define ID_VIEW_TEXTUREMINE 32807
#define ID_VIEW_WIREFRAMEMINE 32808
#define ID_FILE_LEAVE_EDITOR 32809
#define IDM_IMPORT_BITMAP 32810
#define ID_FILE_INFORMATION 32815
#define ID_FILE_CHECKMINE 32816
#define ID_VIEW_ZOOM 32817
#define ID_VIEW_PAN 32819
#define ID_VIEW_CENTERONCUBE 32821
#define ID_VIEW_CENTERONMINE 32823
#define ID_GROUP_CREATEGROUP 32825
#define ID_TOOLS_TEXTURE 32828
#define ID_TOOLS_OBJECT 32829
#define ID_GROUP_SAVEGROUP 32833
#define ID_GROUP_LOADGROUP 32834
#define ID_GROUP_MIRRORGROUP 32835
#define ID_FILE_PREFERENCES 32837
#define ID_TOOLS_TRIGGER 32839
#define ID_TOOLS_WORLD 32840
#define ID_TOOLS_CURVEGENERATOR 32842
#define ID_TOOLS_LIGHTING 32843
#define ID_TOOLS_SEGMENT 32844
#define ID_TOOLS_AI 32845
#define ID_GROUP_SAVEGROUPASGEOMETRIC 32849
#define ID_VIEW_MOVECAMERATOSELECTEDSIDE 32853
#define ID_TOOLS_WALL 32854
#define ID_NUMPAD1 32857
#define ID_NUMPAD2 32858
#define ID_NUMPAD3 32859
#define ID_NUMPAD4 32860
#define ID_NUMPAD5 32861
#define ID_NUMPAD6 32862
#define ID_NUMPAD7 32863
#define ID_NUMPAD8 32864
#define ID_NUMPAD9 32865
#define ID_NUMPAD0 32866
#define ID_NUMPADDEL 32867
#define ID_NUMPADMINUS 32868
#define ID_NUMPADADD 32869
#define ID_APPLYTMAP1TOSIDE 32870
#define ID_APPLYTMAP2TOSIDE 32871
#define ID_FILE_PLAY640X480 32872
#define ID_VIEW_CENTERONOBJECT 32873
#define ID_EDIT_CLEARSELECTED 32874
#define ID_EDIT_ADDSELECT 32875
#define ID_EDIT_REMOVESELECT 32876
#define ID_EDIT_SELECTATTACHED 32877
#define ID_EDIT_LOADSCRAP 32878
#define ID_EDIT_SAVESCRAP 32879
#define ID_EDIT_VIEWSCRAP 32880
#define ID_EDIT_SELECTFROMBOX 32882
#define ID_BUTTON_WINDOWSELECTION 32883
#define ID_TERRAIN_VIEW 32884
#define ID_MINE_VIEW 32885
#define ID_EDIT_DELETE 32886
#define ID_NUMPADENTER 32887
#define ID_NUMPADMUL 32888
#define ID_NUMPADDIV 32889
#define ID_NUMPADLOCK 32890
#define ID_OBJECT_PLACEOBJECT 32891
#define ID_OBJECT_DELETEOBJECT 32892
#define ID_BUTTON_OBJMOVE 32894
#define ID_TOOLS_WORLD_OBJECTS_SOUND 32895
#define ID_TEST_TEST1 32897
#define ID_TEST_TEST2 32898
#define ID_TEST_TEST3 32899
#define ID_EDITORS_AIPROPERTIES 32900
#define ID_BUTTON_LIGHTING 32902
#define ID_EDITORS_MEGACELLS 32903
#define IDD_REORDER_PAGES 32904
#define ID_FILE_IMPORT_ROOM 32905
#define ID_OBJECT_MOVEPLAYER 32907
#define ID_VIEW_NEGATIVELAND 32909
#define ID_ROOM_VIEW 32910
#define ID_VIEW_NEXTVIEWER 32911
#define ID_VIEW_NEWVIEWER 32912
#define ID_VIEW_DELETEVIEWER 32913
#define ID_VIEWER_NEXT 32914
#define ID_D3HELP 32915
#define ID_EDITORS_LEVELSCRIPT 32916
#define ID_EDITORS_DEFAULTSCRIPT 32917
#define ID_ROOM_ADD 32918
#define ID_ROOM_SELECTBYNUMBER 32919
#define ID_ROOM_SELECTBYOBJECT 32920
#define ID_ROOM_SELECTBYTRIGGER 32921
#define ID_ROOM_NEXTFACE 32922
#define ID_ROOM_PREVIOUSFACE 32923
#define ID_ROOM_NEXTROOM 32924
#define ID_ROOM_PREVIOUSROOM 32925
#define ID_ROOM_APPLYTEXTURE 32926
#define ID_ROOM_GRABTEXTURE 32927
#define ID_OSIRIS_IMPORT_SCRIPT 32928
#define ID_OSIRIS_EXPORT_SCRIPT 32929
#define ID_OSIRIS_COMPILE_SCRIPT 32930
#define ID_OSIRIS_CUT 32931
#define ID_OSIRIS_COPY 32932
#define ID_OSIRIS_PASTE 32933
#define ID_OSIRIS_FIND 32934
#define ID_OSIRIS_FIND_AND_REPLACE 32935
#define ID_OSIRIS_SET_EXTERNAL 32936
#define ID_OSIRIS_USE_EXTERNAL 32937
#define ID_OSIRIS_SAVE_EXIT 32938
#define ID_HOTSPOT_TGA 32939
#define ID_ROOM_ATTACHROOM 32940
#define ID_ROOM_SAVECURRENTROOM 32941
#define ID_EDITORS_FILES 32942
#define ID_ROOM_BUILDBRIDGE 32945
#define ID_ROOM_MARK 32946
#define ID_TOOLS_WORLD_OBJECTS_TEST_ROBOTS 32947
#define ID_TOOLS_WORLD_OBJECTS_TEST_POWERUPS 32948
#define ID_TOOLS_WORLD_OBJECTS_DEBRIS 32949
#define ID_TOOLS_WORLD_OBJECTS_BUILDINGS 32950
#define ID_TOOLS_WORLD_OBJECTS_CLUTTER 32951
#define ID_ROOM_PLACEROOM 32954
#define ID_ROOM_UNPLACEROOM 32955
#define ID_ROOM_DELETE 32956
#define ID_EDIT_PLACE 32957
#define ID_EDIT_ATTACH 32958
#define ID_FILE_LEVELPROPS 32959
#define ID_ROOM_SELECTFACEBYNUMBER 32960
#define ID_ZBUTTON 32963
#define ID_ROOM_DROPROOM 32964
#define ID_ROOM_PLACETERRAINROOM 32965
#define ID_ROOM_JOINROOMS 32966
#define ID_ROOM_SWAPMAKEDANDCURRENTROOMFACE 32967
#define ID_OBJBUTTON 32971
#define ID_OBJECT_PLACECAMERAATVIEWER 32972
#define ID_OBJECT_SETCAMERAFROMVIEWER 32973
#define ID_OBJECT_SETVIEWERFROMCAMERA 32974
#define ID_ROOM_DELETEFACE 32976
#define ID_ROOM_SNAPPLACEDROOM 32977
#define ID_EXIT 32979
#define ID_FILE_LEVEL_INFO 32980
#define ID_FILE_STATS 32981
#define ID_FILE_VERIFY_LEVEL 32982
#define ID_ROOM_JOIN_ADJACENT_FACES 32983
#define ID_OBJECT_PLACECAMERAATCURRENTFACE 32984
#define ID_ROOM_PROPAGATETOALL 32985
#define ID_ROOM_SPLITFACE 32986
#define ID_ROOM_DELETEPORTAL 32987
#define ID_SUBEDITORS_TABLEFILEEDIT 32988
#define ID_TABLEEDIT_FILE_LOAD 32989
#define ID_TABLEEDIT_FILE_EXIT 32990
#define ID_TABLEEDIT_FILE_SAVE 32991
#define ID_TABLEEDIT_FILE_SAVE_AS 32992
#define ID_EDITORS_AMBIENTSOUNDS 32993
#define ID_BRIEFING_EDITOR 32994
#define ID_FILE_FIXCRACKS 32995
#define ID_ROOM_SNAPPOINTTOEDGE 32996
#define ID_ROOM_UNDOSNAP 32997
#define ID_ROOM_SNAPPOINTTOPOINT 32998
#define ID_REINIT_OPENGL 32999
#define ID_FILE_REMOVEEXTRAPOINTS 33000
#define ID_EDITORS_OSIRISSTREDIT 33001
#define ID_ROOM_BUILDSMOOTHBRIDGE 33002
#define ID_FORCEFEEDBACK_EDITOR 33003
#define ID_ROOM_JOINROOMSEXACT 33004
#define ID_VIEW_RESETVIEWRADIUS 33005
#define ID_SUBEDITORS_TABLEFILEFILTER 33006
#define ID_TABLEFILTER_FILE_LOAD 33007
#define ID_TABLEFILTER_FILE_SAVE 33008
#define ID_TABLEFILTER_FILE_SAVEAS 33009
#define ID_TABLEFILTER_FILE_EXIT 33010
#define ID_TABLEFILTER_FILE_NEW 33011
#define ID_VIEW_SHOWOBJECTSINWIREFRAMEVIEW 33012
#define ID_SCRIPT_LEVEL_INTERFACE 33013
#define ID_EDITORS_DALLAS 33014
#define ID_ROOM_STARTNEWFACE 33015
#define ID_ROOM_ADDVERTTONEWFACE 33016
#define ID_ROOM_FINISHNEWFACE 33017
#define ID_OSIRISCOMPILE 33018
#define ID_ROOM_RENAMEROOM 33019
#define ID_VIEW_MOVECAMERATOCURRENTOBJECT 33021
#define ID_OBJECT_SELECTBYNUMBER 33022
#define IDD_SHOW_ALL_CHECKED_OUT 33023
#define ID_VIEW_SHOWVIEWERFORWARDVECTOR 33024
#define ID_OBJECT_PLACESOUNDSOURCEATVIEWER 33025
#define ID_ROOM_SETCENTERFROMVIEWER 33026
#define ID_ROOM_CLEARCENTERPOINT 33027
#define IDD_ORPHANHUNTER 33028
#define ID_ROOM_COMBINE 33029
#define ID_FILE_FIXDEGENERATEFACES 33030
#define ID_ROOM_SNAPPOINTTOFACE 33031
#define ID_OBJECT_PLACEWAYPOINTATVIEWER 33032
#define ID_ROOM_LINKTONEWEXTERNAL 33033
#define ID_FILE_SAVEGOALTEXT 33034
#define ID_VIEW_VIEWPROP 33036
#define ID_ROOM_DELETEVERT 33037
#define ID_ROOM_FACE_ADDVERTTOEDGE 33038
#define ID_ROOM_FACE_SPLITFACE 33039
#define ID_ROOM_FACE_DELETEVERTONEDGE 33040
#define ID_ROOM_FACE_MOVEVERTONEDGE 33041
#define ID_VIEW_MOVECAMERATOSELECTEDFACE 33042
#define ID_VIEW_MOVECAMERATOSELECTEDROOM 33043
#define ID_ROOM_MERGEOBJECTINTOROOM 33044
#define ID_EDIT_PLACE_TERRAIN 33045
#define ID_ROOM_DELETECONNECTEDFACES 33046
#define ID_ROOM_ROTATEPLACEDROOM45DEGREES 33049
#define ID_ROOM_PROPAGATETOADJACENTCOPLANARFACES 33050
#define ID_VIEW_FLIP 33051
#define ID_FILE_REMOVEDUPLICATEFACESFROMCURRENTROOM 33052
#define ID_INDICATOR_ENGINE 61204
#define ID_INDICATOR_VIEWER 61205

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS 1
#define _APS_NEXT_RESOURCE_VALUE 283
#define _APS_NEXT_COMMAND_VALUE 33053
#define _APS_NEXT_CONTROL_VALUE 2483
#define _APS_NEXT_SYMED_VALUE 110
#endif
#endif
